(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     97885,       1877]
NotebookOptionsPosition[     92867,       1792]
NotebookOutlinePosition[     93238,       1808]
CellTagsIndexPosition[     93195,       1805]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook demonstrates how derangement (permutation) circuits of the \
Error Suppression by Derangements (ESD) [arXiv:2011.05942] and Virtual \
Distillation (VD) [arXiv:2011.07064] techniques can be constructed and used \
to suppress errors in noisy quantum devices. The approach takes ",
 StyleBox["n",
  FontSlant->"Italic"],
 " copies of a noisy quantum circuit and reduces errors exponentially as ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["Q", "n"], TraditionalForm]],ExpressionUUID->
  "fd7ccc6a-d6de-40c9-8d23-297780096266"],
 ", where ",
 StyleBox["Q",
  FontSlant->"Italic"],
 "<1."
}], "Text",
 CellChangeTimes->{{3.8262650902861843`*^9, 3.826265091099492*^9}, {
   3.8262652312441196`*^9, 3.826265473334661*^9}, {3.8264936657315893`*^9, 
   3.826493710958598*^9}, {3.826493827200305*^9, 3.8264938282809477`*^9}, {
   3.8264939742007303`*^9, 3.82649405518382*^9}, {3.8272392140975666`*^9, 
   3.827239224966739*^9}, {3.827239268488271*^9, 3.8272392931488256`*^9}, {
   3.8272393731400995`*^9, 3.827239508033763*^9}, {3.8272397502116723`*^9, 
   3.8272397561584396`*^9}, {3.827241583498407*^9, 3.8272416495424733`*^9}, 
   3.827244314877225*^9},
 Background->RGBColor[
  0.88, 1, 0.88],ExpressionUUID->"edeb8f40-1ecb-4621-b0ed-e34a18b3ac59"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Definitions", "Section"]], "Subsubsection",
 CellChangeTimes->{{3.826872090791264*^9, 3.826872094622589*^9}, {
  3.826873503854273*^9, 3.82687350457395*^9}, {3.8268874805667534`*^9, 
  3.82688748496704*^9}, {3.8268955676768513`*^9, 3.826895569090865*^9}, {
  3.827239206053363*^9, 
  3.8272392078122063`*^9}},ExpressionUUID->"ba6a1eed-b2ed-4d6f-b84e-\
545b036530a8"],

Cell[TextData[StyleBox["Make sure to run the code below -- but don\
\[CloseCurlyQuote]t worry about the details, these are just definitions of \
the functions our demo will use",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.8262650902861843`*^9, 3.826265091099492*^9}, {
  3.8262652312441196`*^9, 3.826265473334661*^9}, {3.8264936657315893`*^9, 
  3.826493710958598*^9}, {3.826493827200305*^9, 3.8264938282809477`*^9}, {
  3.8264939742007303`*^9, 3.82649405518382*^9}, {3.8272392140975666`*^9, 
  3.827239224966739*^9}, {3.827239268488271*^9, 3.8272392931488256`*^9}},
 Background->RGBColor[
  0.88, 1, 0.88],ExpressionUUID->"fce6512a-b7da-4a04-a168-df801fcf3997"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Import", " ", "QuESTlink"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
    "Import", "[", "\"\<https://qtechtheory.org/QuESTlink.m\>\"", "]"}], 
    ";"}], "\n", 
   RowBox[{
    RowBox[{"CreateDownloadedQuESTEnv", "[", "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "controlled", " ", "SWAP", " ", "operation", " ", "between", " ", "two", 
     " ", "full", " ", "registers"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cSWAPregs", "[", 
     RowBox[{"reg1_", ",", "reg2_", ",", "qubitsperReg_", ",", "controlQB_"}],
      "]"}], ":=", 
    RowBox[{"Table", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       SubscriptBox["C", "controlQB"], "[", 
       SubscriptBox["SWAP", 
        RowBox[{
         RowBox[{
          RowBox[{"reg1", "*", "qubitsperReg"}], "+", "k"}], ",", 
         RowBox[{
          RowBox[{"reg2", "*", "qubitsperReg"}], "+", "k"}]}]], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "0", ",", 
        RowBox[{"qubitsperReg", "-", "1"}]}], "}"}]}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Derangement", " ", "circuit", " ", "for", " ", "2", " ", "copies"}], " ",
     "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"D2", "[", 
     RowBox[{"qubitsperReg_", ",", "observable_"}], "]"}], ":=", " ", 
    RowBox[{"With", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"controlQB", "=", 
        RowBox[{"2", "*", "qubitsperReg"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"{", 
         SubscriptBox["H", "controlQB"], "}"}], ",", 
        RowBox[{"cSWAPregs", "[", 
         RowBox[{
          RowBox[{"reg1", "=", "0"}], ",", 
          RowBox[{"reg2", "=", "1"}], ",", "qubitsperReg", ",", "controlQB"}],
          "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Circuit", "[", 
          RowBox[{"Evaluate", "@", "observable"}], "]"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            SubscriptBox["Id", "n_"], "\[RuleDelayed]", 
            SubscriptBox["Id", 
             RowBox[{"n", "+", "qubitsperReg"}]]}], ",", 
           RowBox[{
            SubscriptBox["O_", "n_"], "\[RuleDelayed]", 
            RowBox[{
             SubscriptBox["C", "controlQB"], "[", 
             SubscriptBox["O", 
              RowBox[{"n", "+", "qubitsperReg"}]], "]"}]}]}], "}"}]}], 
        "\[IndentingNewLine]", ",", 
        RowBox[{"{", 
         SubscriptBox["H", "controlQB"], "}"}]}], "]"}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"txt", "[", "in_", "]"}], ":=", 
    RowBox[{"Text", "[", 
     RowBox[{"Style", "[", 
      RowBox[{"in", ",", 
       RowBox[{"FontFamily", "\[Rule]", "\"\<Times New Roman\>\""}], ",", 
       RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Draw", " ", "derangement", " ", "circuit", " ", "with", " ", 
     "highligting", " ", "the", " ", "different", " ", "registers"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DrawDerangementCircuit", "[", 
     RowBox[{"derangementCirc_", ",", "numQs_", ",", "numCopies_"}], "]"}], ":=", 
    RowBox[{"DrawCircuit", "[", 
     RowBox[{"derangementCirc", ",", " ", "\[IndentingNewLine]", 
      RowBox[{"Epilog", " ", "\[Rule]", " ", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "\[IndentingNewLine]", "\t", 
          RowBox[{
           RowBox[{"FaceForm", "[", "None", "]"}], ",", 
           RowBox[{"EdgeForm", "[", 
            RowBox[{"Directive", "[", 
             RowBox[{"Red", ",", "Dashed"}], "]"}], "]"}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Flatten", "@", 
          RowBox[{"Table", "[", "\[IndentingNewLine]", "\t", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Text", "[", 
               RowBox[{
                RowBox[{"Style", "[", 
                 RowBox[{
                  RowBox[{"StringForm", "[", 
                   RowBox[{"\"\<Reg. ``\>\"", ",", "k"}], "]"}], ",", 
                  RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"0", ",", 
                  RowBox[{
                   RowBox[{"k", "*", "numQs"}], "+", ".4"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"-", "1"}], ",", 
                  RowBox[{"-", "1"}]}], "}"}]}], "]"}], ",", 
              RowBox[{"EdgeForm", "[", 
               RowBox[{"Directive", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"Red", ",", "Blue"}], "}"}], "[", 
                  RowBox[{"[", 
                   RowBox[{
                    RowBox[{"Mod", "[", 
                    RowBox[{"k", ",", "2"}], "]"}], "+", "1"}], "]"}], "]"}], 
                 ",", "Dashed", ",", 
                 RowBox[{"Opacity", "[", "0.4", "]"}]}], "]"}], "]"}], ",", 
              "\[IndentingNewLine]", "\t", 
              RowBox[{"Rectangle", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"0", ",", 
                  RowBox[{
                   RowBox[{"k", "*", "numQs"}], " ", "+", ".2"}]}], "}"}], 
                ",", " ", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Length", "[", "derangementCirc", "]"}], ",", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"k", "+", "1"}], ")"}], "numQs"}], "-", ".2"}]}], 
                 "}"}]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"k", ",", "0", ",", 
              RowBox[{"numCopies", "-", "1"}]}], "}"}]}], "]"}]}]}], 
        "\[IndentingNewLine]", "\t", "]"}]}]}], "\[IndentingNewLine]", 
     "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Create", " ", "n", " ", "copies", " ", "of", " ", "a", " ", 
     RowBox[{"circuit", " ", "--"}], " ", "this", " ", "can", " ", "be", " ", 
     "the", " ", "input", " ", "of", " ", "the", " ", "derangement", " ", 
     "circuit"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CopiesOfCircuit", "[", 
     RowBox[{"circuit_", ",", "numCopies_", ",", "qubitsperReg_"}], "]"}], ":=", 
    RowBox[{"Flatten", "@", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"circuit", "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           SubscriptBox["gate_", "n_"], "\[RuleDelayed]", 
           SubscriptBox["gate", 
            RowBox[{"n", "+", 
             RowBox[{"k", "*", "qubitsperReg"}]}]]}], ",", 
          RowBox[{
           SubscriptBox["gate_", 
            RowBox[{"n1_", ",", "n2_"}]], "\[RuleDelayed]", 
           SubscriptBox["gate", 
            RowBox[{
             RowBox[{"n1", "+", 
              RowBox[{"k", "*", "qubitsperReg"}]}], ",", 
             RowBox[{"n2", "+", 
              RowBox[{"k", "*", "qubitsperReg"}]}]}]]}]}], "}"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", 
         RowBox[{"numCopies", "-", "1"}]}], "}"}]}], "]"}]}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.826872320047923*^9, 3.826872375664239*^9}, {
   3.8268742747755795`*^9, 3.8268742822272253`*^9}, {3.82687434174118*^9, 
   3.826874376918945*^9}, {3.8268749864987783`*^9, 3.826874991161893*^9}, {
   3.8268752429704714`*^9, 3.82687529664655*^9}, {3.826875328084448*^9, 
   3.8268753401067457`*^9}, {3.8268753702989745`*^9, 3.826875385563495*^9}, {
   3.8268768014369926`*^9, 3.826876825748206*^9}, {3.826876970469604*^9, 
   3.8268769889159956`*^9}, {3.826878937370508*^9, 3.826878968473935*^9}, {
   3.826879027773619*^9, 3.8268791533601227`*^9}, {3.8268866460227365`*^9, 
   3.826886646209462*^9}, {3.8268871155670433`*^9, 3.826887184995075*^9}, {
   3.82688721830243*^9, 3.8268872807312207`*^9}, 3.826887466452567*^9, {
   3.826888894358102*^9, 3.8268889063387117`*^9}, {3.826889058608635*^9, 
   3.826889058749688*^9}, {3.826895183513112*^9, 3.826895184815276*^9}, {
   3.826895268561699*^9, 3.8268952838294153`*^9}, {3.8268955196227064`*^9, 
   3.826895553221464*^9}, {3.8268957755181456`*^9, 3.8268958013977785`*^9}, {
   3.8268958504231677`*^9, 3.8268958506788025`*^9}, {3.8268958867799854`*^9, 
   3.8268959690300026`*^9}, {3.826896013723448*^9, 3.826896022739419*^9}, {
   3.8268961072094355`*^9, 3.8268961101365795`*^9}, 3.8268961453220277`*^9, {
   3.8268963362123013`*^9, 3.826896338788127*^9}, 3.8269469396889625`*^9, {
   3.827239302165138*^9, 3.827239302576232*^9}, {3.827239696465516*^9, 
   3.8272396992339907`*^9}, {3.827240518258831*^9, 3.827240525605591*^9}, {
   3.827240662337671*^9, 3.827240666970154*^9}, {3.827240949721363*^9, 
   3.827240950008159*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"206d4c26-824c-4345-86ef-8a66327a263c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1) Derangement (SWAP) circuit for two input \
registers", "Section"]], "Subsubsection",
 CellChangeTimes->{{3.826872090791264*^9, 3.8268721137745934`*^9}, {
  3.826872162007494*^9, 3.826872162855002*^9}, {3.8268758156045923`*^9, 
  3.826875819318865*^9}, {3.826896725458007*^9, 3.8268967287545905`*^9}, {
  3.8268970400065746`*^9, 3.826897043320506*^9}, {3.8269488148312426`*^9, 
  3.8269488240360394`*^9}, {3.827239554936898*^9, 
  3.827239576080586*^9}},ExpressionUUID->"b7b1cfe5-09e0-40fc-95c1-\
309abf21c5d5"],

Cell["We set how many qubits there are in a register ", "Text",
 CellChangeTimes->{{3.8262650902861843`*^9, 3.826265091099492*^9}, {
  3.8262652312441196`*^9, 3.826265473334661*^9}, {3.8264936657315893`*^9, 
  3.826493710958598*^9}, {3.826493827200305*^9, 3.8264938282809477`*^9}, {
  3.8264939742007303`*^9, 3.82649405518382*^9}, {3.8272392140975666`*^9, 
  3.827239224966739*^9}, {3.827239268488271*^9, 3.8272392931488256`*^9}, {
  3.827239343424307*^9, 3.8272393559192715`*^9}, {3.8272395839220505`*^9, 
  3.827239589466489*^9}},
 Background->RGBColor[
  0.88, 1, 0.88],ExpressionUUID->"f2b76694-ba70-4719-849d-be7a4b002b84"],

Cell[BoxData[
 RowBox[{
  RowBox[{"numQs", "=", "5"}], ";"}]], "Input",
 CellLabel->"In[15]:=",ExpressionUUID->"33b879cf-e6ca-4316-b322-098e4ab28a86"],

Cell["\<\
We set the observable we want to measure as products of Pauli operators (note \
that the ESD/VD technique suppresses errors in measuring observables)\
\>", "Text",
 CellChangeTimes->{{3.8262650902861843`*^9, 3.826265091099492*^9}, {
  3.8262652312441196`*^9, 3.826265473334661*^9}, {3.8264936657315893`*^9, 
  3.826493710958598*^9}, {3.826493827200305*^9, 3.8264938282809477`*^9}, {
  3.8264939742007303`*^9, 3.82649405518382*^9}, {3.8272392140975666`*^9, 
  3.827239224966739*^9}, {3.827239268488271*^9, 3.8272392931488256`*^9}, {
  3.827239343424307*^9, 3.8272393559192715`*^9}, {3.8272395839220505`*^9, 
  3.827239589466489*^9}, {3.8272396351556168`*^9, 3.8272396413082952`*^9}, {
  3.8272397375360065`*^9, 3.827239825707959*^9}, {3.8272425752710223`*^9, 
  3.8272425762698393`*^9}},
 Background->RGBColor[
  0.88, 1, 0.88],ExpressionUUID->"886cdb7c-cf6d-4354-acb6-d2664b14e1dc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"observable", "=", 
  RowBox[{"Product", "[", 
   RowBox[{
    SubscriptBox["X", "k"], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "0", ",", 
      RowBox[{"numQs", "-", "1"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8272396274049206`*^9, 3.82723963001959*^9}, {
  3.827239829327709*^9, 3.827239832681346*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"7600486f-d235-451d-9ca0-eba4d35ae8c3"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["X", "0"], " ", 
  SubscriptBox["X", "1"], " ", 
  SubscriptBox["X", "2"], " ", 
  SubscriptBox["X", "3"], " ", 
  SubscriptBox["X", "4"]}]], "Output",
 CellChangeTimes->{{3.8272398338718214`*^9, 3.827239840139904*^9}, 
   3.8272425492426863`*^9, 3.8272428269278116`*^9},
 CellLabel->"Out[16]=",ExpressionUUID->"a6f90732-60c2-4f78-9697-209810cedfff"]
}, Open  ]],

Cell["\<\
The derangement circuit permutes the two input registers Reg. 0 and Reg. 1 \
and then measures the expectation value of the observable\
\>", "Text",
 CellChangeTimes->{{3.8262650902861843`*^9, 3.826265091099492*^9}, {
  3.8262652312441196`*^9, 3.826265473334661*^9}, {3.8264936657315893`*^9, 
  3.826493710958598*^9}, {3.826493827200305*^9, 3.8264938282809477`*^9}, {
  3.8264939742007303`*^9, 3.82649405518382*^9}, {3.8272392140975666`*^9, 
  3.827239224966739*^9}, {3.827239268488271*^9, 3.8272392931488256`*^9}, {
  3.827239343424307*^9, 3.8272393559192715`*^9}, {3.8272395839220505`*^9, 
  3.827239589466489*^9}, {3.8272396351556168`*^9, 3.8272396413082952`*^9}, {
  3.8272397375360065`*^9, 3.827239825707959*^9}, {3.827239859569686*^9, 
  3.8272399451168685`*^9}, {3.8272400455763397`*^9, 3.827240046469738*^9}, {
  3.8272426040148716`*^9, 3.827242648460293*^9}},
 Background->RGBColor[
  0.88, 1, 0.88],ExpressionUUID->"fd25a2a7-3329-44d9-94af-200be9fd104c"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"derangementCirc", "=", 
    RowBox[{"D2", "[", 
     RowBox[{"numQs", ",", "observable"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Draw", " ", "derangement", " ", "circuit", " ", "and", " ", "highligt", 
    " ", "the", " ", "different", " ", "registers"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"DrawDerangementCircuit", "[", 
  RowBox[{"derangementCirc", ",", "numQs", ",", "2"}], "]"}]}], "Input",
 CellChangeTimes->{{3.826896716857791*^9, 3.82689671809296*^9}, {
  3.826896883953436*^9, 3.826896888084891*^9}, {3.826949243537061*^9, 
  3.8269492662886467`*^9}, {3.827239331706195*^9, 3.8272393411201563`*^9}, {
  3.827239599040718*^9, 3.8272396027316003`*^9}, {3.827239861374666*^9, 
  3.8272398640202527`*^9}, {3.8272417742195787`*^9, 3.8272418062722597`*^9}, {
  3.827242419364876*^9, 3.8272424197824864`*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"7c2ec22a-c3ab-4a6c-b74f-3daf75b525f8"],

Cell[BoxData[
 GraphicsBox[
  {EdgeForm[GrayLevel[0]], FaceForm[GrayLevel[
   1]], {{LineBox[{{0, 0.5}, {1, 0.5}}], LineBox[{{0, 1.5}, {1, 1.5}}], 
     LineBox[{{0, 2.5}, {1, 2.5}}], LineBox[{{0, 3.5}, {1, 3.5}}], 
     LineBox[{{0, 4.5}, {1, 4.5}}], LineBox[{{0, 5.5}, {1, 5.5}}], 
     LineBox[{{0, 6.5}, {1, 6.5}}], LineBox[{{0, 7.5}, {1, 7.5}}], 
     LineBox[{{0, 8.5}, {1, 8.5}}], LineBox[{{0, 9.5}, {1, 9.5}}], 
     LineBox[{{0, 10.5}, {1, 10.5}}]}, {LineBox[{{1, 0.5}, {2, 0.5}}], 
     LineBox[{{1, 1.5}, {2, 1.5}}], LineBox[{{1, 2.5}, {2, 2.5}}], 
     LineBox[{{1, 3.5}, {2, 3.5}}], LineBox[{{1, 4.5}, {2, 4.5}}], 
     LineBox[{{1, 5.5}, {2, 5.5}}], LineBox[{{1, 6.5}, {2, 6.5}}], 
     LineBox[{{1, 7.5}, {2, 7.5}}], LineBox[{{1, 8.5}, {2, 8.5}}], 
     LineBox[{{1, 9.5}, {2, 9.5}}], LineBox[{{1, 10.5}, {2, 10.5}}]}, {
     LineBox[{{2, 0.5}, {3, 0.5}}], LineBox[{{2, 1.5}, {3, 1.5}}], 
     LineBox[{{2, 2.5}, {3, 2.5}}], LineBox[{{2, 3.5}, {3, 3.5}}], 
     LineBox[{{2, 4.5}, {3, 4.5}}], LineBox[{{2, 5.5}, {3, 5.5}}], 
     LineBox[{{2, 6.5}, {3, 6.5}}], LineBox[{{2, 7.5}, {3, 7.5}}], 
     LineBox[{{2, 8.5}, {3, 8.5}}], LineBox[{{2, 9.5}, {3, 9.5}}], 
     LineBox[{{2, 10.5}, {3, 10.5}}]}, {LineBox[{{3, 0.5}, {4, 0.5}}], 
     LineBox[{{3, 1.5}, {4, 1.5}}], LineBox[{{3, 2.5}, {4, 2.5}}], 
     LineBox[{{3, 3.5}, {4, 3.5}}], LineBox[{{3, 4.5}, {4, 4.5}}], 
     LineBox[{{3, 5.5}, {4, 5.5}}], LineBox[{{3, 6.5}, {4, 6.5}}], 
     LineBox[{{3, 7.5}, {4, 7.5}}], LineBox[{{3, 8.5}, {4, 8.5}}], 
     LineBox[{{3, 9.5}, {4, 9.5}}], LineBox[{{3, 10.5}, {4, 10.5}}]}, {
     LineBox[{{4, 0.5}, {5, 0.5}}], LineBox[{{4, 1.5}, {5, 1.5}}], 
     LineBox[{{4, 2.5}, {5, 2.5}}], LineBox[{{4, 3.5}, {5, 3.5}}], 
     LineBox[{{4, 4.5}, {5, 4.5}}], LineBox[{{4, 5.5}, {5, 5.5}}], 
     LineBox[{{4, 6.5}, {5, 6.5}}], LineBox[{{4, 7.5}, {5, 7.5}}], 
     LineBox[{{4, 8.5}, {5, 8.5}}], LineBox[{{4, 9.5}, {5, 9.5}}], 
     LineBox[{{4, 10.5}, {5, 10.5}}]}, {LineBox[{{5, 0.5}, {6, 0.5}}], 
     LineBox[{{5, 1.5}, {6, 1.5}}], LineBox[{{5, 2.5}, {6, 2.5}}], 
     LineBox[{{5, 3.5}, {6, 3.5}}], LineBox[{{5, 4.5}, {6, 4.5}}], 
     LineBox[{{5, 5.5}, {6, 5.5}}], LineBox[{{5, 6.5}, {6, 6.5}}], 
     LineBox[{{5, 7.5}, {6, 7.5}}], LineBox[{{5, 8.5}, {6, 8.5}}], 
     LineBox[{{5, 9.5}, {6, 9.5}}], LineBox[{{5, 10.5}, {6, 10.5}}]}, {
     LineBox[{{6, 0.5}, {7, 0.5}}], LineBox[{{6, 1.5}, {7, 1.5}}], 
     LineBox[{{6, 2.5}, {7, 2.5}}], LineBox[{{6, 3.5}, {7, 3.5}}], 
     LineBox[{{6, 4.5}, {7, 4.5}}], LineBox[{{6, 5.5}, {7, 5.5}}], 
     LineBox[{{6, 6.5}, {7, 6.5}}], LineBox[{{6, 7.5}, {7, 7.5}}], 
     LineBox[{{6, 8.5}, {7, 8.5}}], LineBox[{{6, 9.5}, {7, 9.5}}], 
     LineBox[{{6, 10.5}, {7, 10.5}}]}, {LineBox[{{7, 0.5}, {8, 0.5}}], 
     LineBox[{{7, 1.5}, {8, 1.5}}], LineBox[{{7, 2.5}, {8, 2.5}}], 
     LineBox[{{7, 3.5}, {8, 3.5}}], LineBox[{{7, 4.5}, {8, 4.5}}], 
     LineBox[{{7, 5.5}, {8, 5.5}}], LineBox[{{7, 6.5}, {8, 6.5}}], 
     LineBox[{{7, 7.5}, {8, 7.5}}], LineBox[{{7, 8.5}, {8, 8.5}}], 
     LineBox[{{7, 9.5}, {8, 9.5}}], LineBox[{{7, 10.5}, {8, 10.5}}]}, {
     LineBox[{{8, 0.5}, {9, 0.5}}], LineBox[{{8, 1.5}, {9, 1.5}}], 
     LineBox[{{8, 2.5}, {9, 2.5}}], LineBox[{{8, 3.5}, {9, 3.5}}], 
     LineBox[{{8, 4.5}, {9, 4.5}}], LineBox[{{8, 5.5}, {9, 5.5}}], 
     LineBox[{{8, 6.5}, {9, 6.5}}], LineBox[{{8, 7.5}, {9, 7.5}}], 
     LineBox[{{8, 8.5}, {9, 8.5}}], LineBox[{{8, 9.5}, {9, 9.5}}], 
     LineBox[{{8, 10.5}, {9, 10.5}}]}, {LineBox[{{9, 0.5}, {10, 0.5}}], 
     LineBox[{{9, 1.5}, {10, 1.5}}], LineBox[{{9, 2.5}, {10, 2.5}}], 
     LineBox[{{9, 3.5}, {10, 3.5}}], LineBox[{{9, 4.5}, {10, 4.5}}], 
     LineBox[{{9, 5.5}, {10, 5.5}}], LineBox[{{9, 6.5}, {10, 6.5}}], 
     LineBox[{{9, 7.5}, {10, 7.5}}], LineBox[{{9, 8.5}, {10, 8.5}}], 
     LineBox[{{9, 9.5}, {10, 9.5}}], LineBox[{{9, 10.5}, {10, 10.5}}]}, {
     LineBox[{{10, 0.5}, {11, 0.5}}], LineBox[{{10, 1.5}, {11, 1.5}}], 
     LineBox[{{10, 2.5}, {11, 2.5}}], LineBox[{{10, 3.5}, {11, 3.5}}], 
     LineBox[{{10, 4.5}, {11, 4.5}}], LineBox[{{10, 5.5}, {11, 5.5}}], 
     LineBox[{{10, 6.5}, {11, 6.5}}], LineBox[{{10, 7.5}, {11, 7.5}}], 
     LineBox[{{10, 8.5}, {11, 8.5}}], LineBox[{{10, 9.5}, {11, 9.5}}], 
     LineBox[{{10, 10.5}, {11, 10.5}}]}, {LineBox[{{11, 0.5}, {12, 0.5}}], 
     LineBox[{{11, 1.5}, {12, 1.5}}], LineBox[{{11, 2.5}, {12, 2.5}}], 
     LineBox[{{11, 3.5}, {12, 3.5}}], LineBox[{{11, 4.5}, {12, 4.5}}], 
     LineBox[{{11, 5.5}, {12, 5.5}}], LineBox[{{11, 6.5}, {12, 6.5}}], 
     LineBox[{{11, 7.5}, {12, 7.5}}], LineBox[{{11, 8.5}, {12, 8.5}}], 
     LineBox[{{11, 9.5}, {12, 9.5}}], LineBox[{{11, 10.5}, {12, 10.5}}]}}, {{
     RectangleBox[{0.1, 10.1}, {0.9, 10.9}], 
     InsetBox["\<\"H\"\>", {0.5, 10.5}]}, {
     {FaceForm[GrayLevel[0]], DiskBox[{1.5, 10.5}, 0.1], 
      LineBox[{{1.5, 0.5}, {1.5, 
       10.5}}]}, {{{LineBox[{{1.4, 0.4}, {1.6, 0.6}}], 
        LineBox[{{1.6, 0.4}, {1.4, 0.6}}]}, {
        LineBox[{{1.4, 5.4}, {1.6, 5.6}}], 
        LineBox[{{1.6, 5.4}, {1.4, 5.6}}]}}, 
      LineBox[{{1.5, 0.5}, {1.5, 5.5}}]}}, {
     {FaceForm[GrayLevel[0]], DiskBox[{2.5, 10.5}, 0.1], 
      LineBox[{{2.5, 1.5}, {2.5, 
       10.5}}]}, {{{LineBox[{{2.4, 1.4}, {2.6, 1.6}}], 
        LineBox[{{2.6, 1.4}, {2.4, 1.6}}]}, {
        LineBox[{{2.4, 6.4}, {2.6, 6.6}}], 
        LineBox[{{2.6, 6.4}, {2.4, 6.6}}]}}, 
      LineBox[{{2.5, 1.5}, {2.5, 6.5}}]}}, {
     {FaceForm[GrayLevel[0]], DiskBox[{3.5, 10.5}, 0.1], 
      LineBox[{{3.5, 2.5}, {3.5, 
       10.5}}]}, {{{LineBox[{{3.4, 2.4}, {3.6, 2.6}}], 
        LineBox[{{3.6, 2.4}, {3.4, 2.6}}]}, {
        LineBox[{{3.4, 7.4}, {3.6, 7.6}}], 
        LineBox[{{3.6, 7.4}, {3.4, 7.6}}]}}, 
      LineBox[{{3.5, 2.5}, {3.5, 7.5}}]}}, {
     {FaceForm[GrayLevel[0]], DiskBox[{4.5, 10.5}, 0.1], 
      LineBox[{{4.5, 3.5}, {4.5, 
       10.5}}]}, {{{LineBox[{{4.4, 3.4}, {4.6, 3.6}}], 
        LineBox[{{4.6, 3.4}, {4.4, 3.6}}]}, {
        LineBox[{{4.4, 8.4}, {4.6, 8.6}}], 
        LineBox[{{4.6, 8.4}, {4.4, 8.6}}]}}, 
      LineBox[{{4.5, 3.5}, {4.5, 8.5}}]}}, {
     {FaceForm[GrayLevel[0]], DiskBox[{5.5, 10.5}, 0.1], 
      LineBox[{{5.5, 4.5}, {5.5, 
       10.5}}]}, {{{LineBox[{{5.4, 4.4}, {5.6, 4.6}}], 
        LineBox[{{5.6, 4.4}, {5.4, 4.6}}]}, {
        LineBox[{{5.4, 9.4}, {5.6, 9.6}}], 
        LineBox[{{5.6, 9.4}, {5.4, 9.6}}]}}, 
      LineBox[{{5.5, 4.5}, {5.5, 9.5}}]}}, {
     {FaceForm[GrayLevel[0]], DiskBox[{6.5, 10.5}, 0.1], 
      LineBox[{{6.5, 5.5}, {6.5, 10.5}}]}, {CircleBox[{6.5, 5.5}, 0.25], 
      LineBox[{{6.5, 5.25}, {6.5, 5.75}}]}}, {
     {FaceForm[GrayLevel[0]], DiskBox[{7.5, 10.5}, 0.1], 
      LineBox[{{7.5, 6.5}, {7.5, 10.5}}]}, {CircleBox[{7.5, 6.5}, 0.25], 
      LineBox[{{7.5, 6.25}, {7.5, 6.75}}]}}, {
     {FaceForm[GrayLevel[0]], DiskBox[{8.5, 10.5}, 0.1], 
      LineBox[{{8.5, 7.5}, {8.5, 10.5}}]}, {CircleBox[{8.5, 7.5}, 0.25], 
      LineBox[{{8.5, 7.25}, {8.5, 7.75}}]}}, {
     {FaceForm[GrayLevel[0]], DiskBox[{9.5, 10.5}, 0.1], 
      LineBox[{{9.5, 8.5}, {9.5, 10.5}}]}, {CircleBox[{9.5, 8.5}, 0.25], 
      LineBox[{{9.5, 8.25}, {9.5, 8.75}}]}}, {
     {FaceForm[GrayLevel[0]], DiskBox[{10.5, 10.5}, 0.1], 
      LineBox[{{10.5, 9.5}, {10.5, 10.5}}]}, {CircleBox[{10.5, 9.5}, 0.25], 
      LineBox[{{10.5, 9.25}, {10.5, 9.75}}]}}, {
     RectangleBox[{11.1, 10.1}, {11.9, 10.9}], 
     InsetBox["\<\"H\"\>", {11.5, 10.5}]}}},
  Epilog->{
    FaceForm[None], 
    EdgeForm[
     Directive[
      RGBColor[1, 0, 0], 
      Dashing[{Small, Small}]]], 
    InsetBox[
     FormBox[
      StyleBox[
       InterpretationBox[
       "\"Reg. \\!\\(\\*FormBox[\\\"0\\\", TraditionalForm]\\)\"", 
        StringForm["Reg. ``", 0], Editable -> False], FontSize -> 12, 
       StripOnInput -> False], TraditionalForm], {0, 0.4}, {-1, -1}], 
    EdgeForm[
     Directive[
      RGBColor[1, 0, 0], 
      Dashing[{Small, Small}], 
      Opacity[0.4]]], 
    RectangleBox[{0, 0.2}, {12, 4.8}], 
    InsetBox[
     FormBox[
      StyleBox[
       InterpretationBox[
       "\"Reg. \\!\\(\\*FormBox[\\\"1\\\", TraditionalForm]\\)\"", 
        StringForm["Reg. ``", 1], Editable -> False], FontSize -> 12, 
       StripOnInput -> False], TraditionalForm], {0, 5.4}, {-1, -1}], 
    EdgeForm[
     Directive[
      RGBColor[0, 0, 1], 
      Dashing[{Small, Small}], 
      Opacity[0.4]]], 
    RectangleBox[{0, 5.2}, {12, 9.8}]},
  ImageSize->360,
  Method->{"ShrinkWrap" -> True}]], "Output",
 CellChangeTimes->{{3.8268967196894593`*^9, 3.826896730317161*^9}, {
   3.826896891698201*^9, 3.826896897797913*^9}, 3.8268974451401486`*^9, 
   3.8269469487498813`*^9, 3.8269488262581396`*^9, 3.8269492668134212`*^9, 
   3.8269500869846773`*^9, 3.8269511237750664`*^9, 3.8272399462214627`*^9, {
   3.8272417952866077`*^9, 3.827241807469164*^9}, 3.8272424202340317`*^9, 
   3.8272425493193226`*^9, 3.8272428270272455`*^9},
 CellLabel->"Out[18]=",ExpressionUUID->"caa979f5-143c-4b95-8228-8642906ad792"]
}, Open  ]],

Cell["\<\
Total number of qubits we need to simulate (2 registers and 1 ancilla qubit)\
\>", "Text",
 CellChangeTimes->{{3.8262650902861843`*^9, 3.826265091099492*^9}, {
  3.8262652312441196`*^9, 3.826265473334661*^9}, {3.8264936657315893`*^9, 
  3.826493710958598*^9}, {3.826493827200305*^9, 3.8264938282809477`*^9}, {
  3.8264939742007303`*^9, 3.82649405518382*^9}, {3.8272392140975666`*^9, 
  3.827239224966739*^9}, {3.827239268488271*^9, 3.8272392931488256`*^9}, {
  3.827239343424307*^9, 3.8272393559192715`*^9}, {3.8272395839220505`*^9, 
  3.827239589466489*^9}, {3.8272396351556168`*^9, 3.8272396413082952`*^9}, {
  3.8272397375360065`*^9, 3.827239825707959*^9}, {3.827239859569686*^9, 
  3.8272399451168685`*^9}, {3.8272400455763397`*^9, 3.827240046469738*^9}, {
  3.8272424277439604`*^9, 3.827242459083147*^9}},
 Background->RGBColor[
  0.88, 1, 0.88],ExpressionUUID->"f06827d5-1426-498f-b0de-e1c893feff36"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"totNumQ", "=", 
  RowBox[{
   RowBox[{"2", "*", "numQs"}], "+", "1"}]}]], "Input",
 CellChangeTimes->{{3.827242436860159*^9, 3.827242438592475*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"ab8e87a1-8c7b-4f59-be5f-f60e74fc8f72"],

Cell[BoxData["11"], "Output",
 CellChangeTimes->{{3.8272424405943995`*^9, 3.827242459971257*^9}, 
   3.827242549352927*^9, 3.8272428270910044`*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"53318b51-e05f-4b41-a19f-ab84fb5b1ca5"]
}, Open  ]]
}, Open  ]],

Cell[TextData[StyleBox["2) Mitigate errors in noisy circuits", "Section"]], \
"Subsubsection",
 CellChangeTimes->{{3.826872090791264*^9, 3.8268721137745934`*^9}, {
  3.826872162007494*^9, 3.826872162855002*^9}, {3.8268758156045923`*^9, 
  3.826875819318865*^9}, {3.8268761409065065`*^9, 3.8268761426449947`*^9}, {
  3.8268892945064564`*^9, 3.826889318494529*^9}, {3.82689704773733*^9, 
  3.826897048300024*^9}},ExpressionUUID->"abf6446b-d090-41d9-9302-\
d2b290512760"],

Cell[CellGroupData[{

Cell["Noisy circuit that generates GHZ states", "Subsubsection",
 CellChangeTimes->{{3.826896847411879*^9, 3.8268970043639135`*^9}, {
  3.826897063849805*^9, 
  3.8268970823266745`*^9}},ExpressionUUID->"ac34b76b-d8c3-48a3-b731-\
92eb0e349739"],

Cell[TextData[{
 "Construct a noisy quantum circuit that generates an ",
 StyleBox["n",
  FontSlant->"Italic"],
 "-qubit GHZ state (|0,0,0,0,0\[RightAngleBracket]+|1,1,1,1,1\
\[RightAngleBracket])/",
 Cell[BoxData[
  SqrtBox["2"]],ExpressionUUID->"dbdfb735-556f-469a-ab5b-207e63e56b45"],
 " with noise rate \[Epsilon]"
}], "Text",
 CellChangeTimes->{{3.8262650902861843`*^9, 3.826265091099492*^9}, {
   3.8262652312441196`*^9, 3.826265473334661*^9}, {3.8264936657315893`*^9, 
   3.826493710958598*^9}, {3.826493827200305*^9, 3.8264938282809477`*^9}, {
   3.8264939742007303`*^9, 3.82649405518382*^9}, {3.8272392140975666`*^9, 
   3.827239224966739*^9}, {3.827239268488271*^9, 3.8272392931488256`*^9}, {
   3.827239343424307*^9, 3.8272393559192715`*^9}, {3.8272395839220505`*^9, 
   3.827239589466489*^9}, {3.827240071375389*^9, 3.8272400906643705`*^9}, {
   3.8272401554151773`*^9, 3.8272401678247633`*^9}, {3.8272402594347553`*^9, 
   3.827240276773361*^9}, {3.8272403088310623`*^9, 3.8272403260443497`*^9}, {
   3.827240477147238*^9, 3.8272404849000597`*^9}, 3.8272442980278726`*^9},
 Background->RGBColor[
  0.88, 1, 0.88],ExpressionUUID->"a6f2a76d-5e5d-4f63-996d-35b069580392"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Epsilon]", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"noisyGHZcirc", "=", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"{", 
      SubscriptBox["H", 
       RowBox[{"numQs", "-", "1"}]], "}"}], ",", 
     RowBox[{"Flatten", "@", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           SubscriptBox["C", "n"], "[", 
           SubscriptBox["X", 
            RowBox[{"n", "-", "1"}]], "]"}], ",", 
          RowBox[{
           SubscriptBox["Depol", 
            RowBox[{"n", ",", 
             RowBox[{"n", "-", "1"}]}]], "[", "\[Epsilon]", "]"}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", 
          RowBox[{"numQs", "-", "1"}], ",", "1", ",", 
          RowBox[{"-", "1"}]}], "}"}]}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DrawCircuit", "[", "noisyGHZcirc", "]"}]}], "Input",
 CellChangeTimes->{{3.8272407844440813`*^9, 3.8272407958962717`*^9}},
 CellLabel->"In[20]:=",ExpressionUUID->"10b0ac48-97dc-425f-8ed4-7dc62a8118a4"],

Cell[BoxData[
 GraphicsBox[
  {EdgeForm[GrayLevel[0]], FaceForm[GrayLevel[
   1]], {{LineBox[{{0, 0.5}, {1, 0.5}}], LineBox[{{0, 1.5}, {1, 1.5}}], 
     LineBox[{{0, 2.5}, {1, 2.5}}], LineBox[{{0, 3.5}, {1, 3.5}}], 
     LineBox[{{0, 4.5}, {1, 4.5}}]}, {LineBox[{{1, 0.5}, {2, 0.5}}], 
     LineBox[{{1, 1.5}, {2, 1.5}}], LineBox[{{1, 2.5}, {2, 2.5}}], 
     LineBox[{{1, 3.5}, {2, 3.5}}], LineBox[{{1, 4.5}, {2, 4.5}}]}, {
     LineBox[{{2, 0.5}, {3, 0.5}}], LineBox[{{2, 1.5}, {3, 1.5}}], 
     LineBox[{{2, 2.5}, {3, 2.5}}], LineBox[{{2, 3.5}, {3, 3.5}}], 
     LineBox[{{2, 4.5}, {3, 4.5}}]}, {LineBox[{{3, 0.5}, {4, 0.5}}], 
     LineBox[{{3, 1.5}, {4, 1.5}}], LineBox[{{3, 2.5}, {4, 2.5}}], 
     LineBox[{{3, 3.5}, {4, 3.5}}], LineBox[{{3, 4.5}, {4, 4.5}}]}, {
     LineBox[{{4, 0.5}, {5, 0.5}}], LineBox[{{4, 1.5}, {5, 1.5}}], 
     LineBox[{{4, 2.5}, {5, 2.5}}], LineBox[{{4, 3.5}, {5, 3.5}}], 
     LineBox[{{4, 4.5}, {5, 4.5}}]}, {LineBox[{{5, 0.5}, {6, 0.5}}], 
     LineBox[{{5, 1.5}, {6, 1.5}}], LineBox[{{5, 2.5}, {6, 2.5}}], 
     LineBox[{{5, 3.5}, {6, 3.5}}], LineBox[{{5, 4.5}, {6, 4.5}}]}, {
     LineBox[{{6, 0.5}, {7, 0.5}}], LineBox[{{6, 1.5}, {7, 1.5}}], 
     LineBox[{{6, 2.5}, {7, 2.5}}], LineBox[{{6, 3.5}, {7, 3.5}}], 
     LineBox[{{6, 4.5}, {7, 4.5}}]}, {LineBox[{{7, 0.5}, {8, 0.5}}], 
     LineBox[{{7, 1.5}, {8, 1.5}}], LineBox[{{7, 2.5}, {8, 2.5}}], 
     LineBox[{{7, 3.5}, {8, 3.5}}], LineBox[{{7, 4.5}, {8, 4.5}}]}, {
     LineBox[{{8, 0.5}, {9, 0.5}}], LineBox[{{8, 1.5}, {9, 1.5}}], 
     LineBox[{{8, 2.5}, {9, 2.5}}], LineBox[{{8, 3.5}, {9, 3.5}}], 
     LineBox[{{8, 4.5}, {9, 4.5}}]}}, {{RectangleBox[{0.1, 4.1}, {0.9, 4.9}], 
     InsetBox["\<\"H\"\>", {0.5, 4.5}]}, {
     {FaceForm[GrayLevel[0]], DiskBox[{1.5, 4.5}, 0.1], 
      LineBox[{{1.5, 3.5}, {1.5, 4.5}}]}, {CircleBox[{1.5, 3.5}, 0.25], 
      LineBox[{{1.5, 3.25}, {1.5, 3.75}}]}}, 
    {EdgeForm[Dashing[{Small, Small}]], RectangleBox[{2.1, 3.1}, {2.9, 4.9}], 
     InsetBox["\<\"\[CapitalDelta]\"\>", {2.5, 4.}]}, {
     {FaceForm[GrayLevel[0]], DiskBox[{3.5, 3.5}, 0.1], 
      LineBox[{{3.5, 2.5}, {3.5, 3.5}}]}, {CircleBox[{3.5, 2.5}, 0.25], 
      LineBox[{{3.5, 2.25}, {3.5, 2.75}}]}}, 
    {EdgeForm[Dashing[{Small, Small}]], RectangleBox[{4.1, 2.1}, {4.9, 3.9}], 
     InsetBox["\<\"\[CapitalDelta]\"\>", {4.5, 3.}]}, {
     {FaceForm[GrayLevel[0]], DiskBox[{5.5, 2.5}, 0.1], 
      LineBox[{{5.5, 1.5}, {5.5, 2.5}}]}, {CircleBox[{5.5, 1.5}, 0.25], 
      LineBox[{{5.5, 1.25}, {5.5, 1.75}}]}}, 
    {EdgeForm[Dashing[{Small, Small}]], RectangleBox[{6.1, 1.1}, {6.9, 2.9}], 
     InsetBox["\<\"\[CapitalDelta]\"\>", {6.5, 2.}]}, {
     {FaceForm[GrayLevel[0]], DiskBox[{7.5, 1.5}, 0.1], 
      LineBox[{{7.5, 0.5}, {7.5, 1.5}}]}, {CircleBox[{7.5, 0.5}, 0.25], 
      LineBox[{{7.5, 0.25}, {7.5, 0.75}}]}}, 
    {EdgeForm[Dashing[{Small, Small}]], RectangleBox[{8.1, 0.1}, {8.9, 1.9}], 
     InsetBox["\<\"\[CapitalDelta]\"\>", {8.5, 1.}]}}},
  ImageSize->270,
  Method->{"ShrinkWrap" -> True}]], "Output",
 CellChangeTimes->{3.8272401152471304`*^9, 3.827240800837163*^9, 
  3.8272409541826577`*^9, 3.8272409910480576`*^9, 3.827242549412995*^9, 
  3.827242827151608*^9},
 CellLabel->"Out[22]=",ExpressionUUID->"a370b5c7-5fe8-4b3d-837c-8641716e0955"]
}, Open  ]],

Cell["Simulate the noisy circuit using QuESTlink", "Text",
 CellChangeTimes->{{3.8262650902861843`*^9, 3.826265091099492*^9}, {
  3.8262652312441196`*^9, 3.826265473334661*^9}, {3.8264936657315893`*^9, 
  3.826493710958598*^9}, {3.826493827200305*^9, 3.8264938282809477`*^9}, {
  3.8264939742007303`*^9, 3.82649405518382*^9}, {3.8272392140975666`*^9, 
  3.827239224966739*^9}, {3.827239268488271*^9, 3.8272392931488256`*^9}, {
  3.827239343424307*^9, 3.8272393559192715`*^9}, {3.8272395839220505`*^9, 
  3.827239589466489*^9}, {3.827240071375389*^9, 3.8272400906643705`*^9}, {
  3.8272401554151773`*^9, 3.8272401678247633`*^9}, {3.8272402594347553`*^9, 
  3.827240276773361*^9}, {3.8272403088310623`*^9, 3.8272404918762016`*^9}, {
  3.8272407721152735`*^9, 3.8272407728647995`*^9}, {3.827240808213707*^9, 
  3.827240831829824*^9}, {3.8272408709293575`*^9, 3.8272409191221933`*^9}, {
  3.8272409564758945`*^9, 3.8272409784577303`*^9}},
 Background->RGBColor[
  0.88, 1, 0.88],ExpressionUUID->"ea961777-5a5f-4964-bd20-556aa961db21"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\[Rho]", ",", "\[Phi]"}], "}"}], "=", 
   RowBox[{"CreateDensityQuregs", "[", 
    RowBox[{"numQs", ",", "2"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ApplyCircuit", "[", 
   RowBox[{"noisyGHZcirc", ",", 
    RowBox[{"InitZeroState", "@", "\[Rho]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8272408985309916`*^9, 3.827240904488909*^9}},
 CellLabel->"In[23]:=",ExpressionUUID->"dfe7c3e3-6b1c-4042-b3ea-646cacc55456"],

Cell[TextData[{
 "Compute the error of the expectation value \[LeftAngleBracket]",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["X", "0"], " ", 
   SubscriptBox["X", "1"], " ", 
   SubscriptBox["X", "2"], " ", 
   SubscriptBox["X", "3"], " ", 
   SubscriptBox["X", "4"]}]],
  CellChangeTimes->{{3.8272398338718214`*^9, 3.827239840139904*^9}},
  ExpressionUUID->"668474f4-afd3-4d18-abf3-64392cb976b5"],
 "\[RightAngleBracket]"
}], "Text",
 CellChangeTimes->{{3.8262650902861843`*^9, 3.826265091099492*^9}, {
   3.8262652312441196`*^9, 3.826265473334661*^9}, {3.8264936657315893`*^9, 
   3.826493710958598*^9}, {3.826493827200305*^9, 3.8264938282809477`*^9}, {
   3.8264939742007303`*^9, 3.82649405518382*^9}, {3.8272392140975666`*^9, 
   3.827239224966739*^9}, {3.827239268488271*^9, 3.8272392931488256`*^9}, {
   3.827239343424307*^9, 3.8272393559192715`*^9}, {3.8272395839220505`*^9, 
   3.827239589466489*^9}, {3.827240071375389*^9, 3.8272400906643705`*^9}, {
   3.8272401554151773`*^9, 3.8272401678247633`*^9}, {3.8272402594347553`*^9, 
   3.827240276773361*^9}, {3.8272403088310623`*^9, 3.8272404918762016`*^9}, {
   3.8272407721152735`*^9, 3.8272407728647995`*^9}, {3.827240808213707*^9, 
   3.827240831829824*^9}, 3.8272409247161636`*^9, {3.8272411807599983`*^9, 
   3.8272411808724875`*^9}},
 Background->RGBColor[
  0.88, 1, 0.88],ExpressionUUID->"58d5db4f-a10f-4166-922d-697cc41f016d"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"idealExpectation", "=", "1."}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"observable", "'"}], "s", " ", "known", " ", "ideal", " ", 
    "expectation", " ", "value", " ", "is", " ", "1"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"unmitigatedError", "=", 
  RowBox[{"Abs", "[", 
   RowBox[{
    RowBox[{"CalcExpecPauliSum", "[", 
     RowBox[{"\[Rho]", ",", "observable", ",", "\[Phi]"}], "]"}], "-", 
    "idealExpectation"}], "]"}], " "}]}], "Input",
 CellChangeTimes->CompressedData["
1:eJwdzn0s1HEcB/CjjZjFNa4Nk2tNbnk483AXlof6y3AP3VB0LmatkB6upA6z
Uy7yuNz1wF9xwpBjuW6WHua0k2ZHyWNhLPJ0l0qL0+/9/eOz1z7v7fPATMsR
ZljTaLRQquDMSPNCRdFKlPihwAS96zR7KynL2n7YQQPnCBM2PHYKg7rqoQg4
qjZFw1LBn1iYuLQ/Dsar1UJ4ydbrIpTIDaoqyp7eMSI3PUA4QemcLhJB1qF3
Zl85tY8r3oHD3p2OfpT8YQMDhg/aFPtTquuH78Ckq5GlMG3d2Ag/mtmt8JXe
RQN5szMDsJMz+R5WVAx8gD0/JUPQcdfVCD2YlhEoT5wbg8+ba8fhckTONCyc
qpqHytG7G7DsVpwJhuTRf5E8e3aX/OVJt2FTiv+5OMB4duZRSMv/Rgxzn+DB
lXZDKgw/EFMIZSeiHpH+mbweqvg6YnHWWgN8yQhugrd/n2uDsYMtRrjVqByH
T3nL0+SeZH0BtqbYLsI+Rd8yrKoU/IV7lFm0AMp7rvZW0P3KNTuY+ybXHt5f
a3CCBatuDBgZ8ckTFvZrWZB7OckfSs1niIv9qhA4WqPnwFMJAdFQcz2I6J7R
uxtEeUNOpwVTToWu+sGYFAuRk6oKhD1pdUT2BSEfco/zRJAfu50FzUU+OXCr
YOImVNcy82HeSJeGC1+3dMHxJrFzKKXPkp6Yue6XNIs5qfdpGBwok0OPknLi
F/73EqiVMhRQlGx8AN+el9TCs6x0DZSFzRO1bh0voL1XuxbOP8nWw7iv3Z9h
b7vABBPKPTehVUfyNpzJ3NiBpTEK6znKbrdW4uF9ShaU1fj7Qh+dQzg8eKya
uKk4OQkt9GrifwCe3Wg=
  "],
 CellLabel->"In[25]:=",ExpressionUUID->"652dfccf-a0aa-4311-88df-76a7a9e5acf9"],

Cell[BoxData["0.041988841573136204`"], "Output",
 CellChangeTimes->{{3.8272404980096445`*^9, 3.827240501140709*^9}, 
   3.8272405416475782`*^9, 3.827240631921486*^9, 3.827240697606544*^9, {
   3.827240987081685*^9, 3.827240994813222*^9}, {3.827241310374174*^9, 
   3.827241324927499*^9}, 3.827241445399884*^9, 3.827242549474279*^9, 
   3.827242827218999*^9},
 CellLabel->"Out[26]=",ExpressionUUID->"863bc678-62ea-4efd-8d9a-6443f29192c0"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Simulate derangement circuits: virtual distillation of 2 noisy GHZ states\
\>", "Subsubsection",
 CellChangeTimes->{{3.826896847411879*^9, 3.8268970043639135`*^9}, {
  3.826897063849805*^9, 3.8268970823266745`*^9}, {3.826897132584563*^9, 
  3.826897168586799*^9}, {3.827241011317442*^9, 3.827241065564728*^9}, {
  3.8272413367636023`*^9, 3.8272413752423697`*^9}, {3.827241708082327*^9, 
  3.827241722642288*^9}, {3.827241851020362*^9, 3.827241866636064*^9}, {
  3.8272427295402117`*^9, 
  3.8272427349929285`*^9}},ExpressionUUID->"9dae5ff9-7f30-4a2f-9128-\
8a0abdd94fc0"],

Cell[TextData[{
 "Set up derangement circuit with two input GHZ circuits (for measuring the \
expectation value \[LeftAngleBracket]",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["X", "0"], " ", 
   SubscriptBox["X", "1"], " ", 
   SubscriptBox["X", "2"], " ", 
   SubscriptBox["X", "3"], " ", 
   SubscriptBox["X", "4"]}]],
  CellChangeTimes->{{3.8272398338718214`*^9, 3.827239840139904*^9}},
  ExpressionUUID->"04961aa7-0ee1-4e90-90f6-2f60fcbf7945"],
 "\[RightAngleBracket])"
}], "Text",
 CellChangeTimes->{{3.8262650902861843`*^9, 3.826265091099492*^9}, {
   3.8262652312441196`*^9, 3.826265473334661*^9}, {3.8264936657315893`*^9, 
   3.826493710958598*^9}, {3.826493827200305*^9, 3.8264938282809477`*^9}, {
   3.8264939742007303`*^9, 3.82649405518382*^9}, {3.8272392140975666`*^9, 
   3.827239224966739*^9}, {3.827239268488271*^9, 3.8272392931488256`*^9}, {
   3.827239343424307*^9, 3.8272393559192715`*^9}, {3.8272395839220505`*^9, 
   3.827239589466489*^9}, {3.827240071375389*^9, 3.8272400906643705`*^9}, {
   3.8272401554151773`*^9, 3.8272401678247633`*^9}, {3.8272402594347553`*^9, 
   3.827240276773361*^9}, {3.8272403088310623`*^9, 3.8272404918762016`*^9}, {
   3.8272407721152735`*^9, 3.8272407728647995`*^9}, {3.827240808213707*^9, 
   3.827240831829824*^9}, 3.8272409247161636`*^9, {3.82724109514158*^9, 
   3.8272411110757155`*^9}, {3.8272412662454457`*^9, 3.827241277609026*^9}, {
   3.8272413955199404`*^9, 3.827241414925856*^9}, 3.8272427456679688`*^9},
 Background->RGBColor[
  0.88, 1, 0.88],ExpressionUUID->"dd6b1fdb-4cef-4926-a9c6-8a959386b219"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"derangementCirc", "=", 
   RowBox[{"D2", "[", 
    RowBox[{"numQs", ",", "observable"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fullCirc", "=", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"CopiesOfCircuit", "[", 
      RowBox[{"noisyGHZcirc", ",", "2", ",", "numQs"}], "]"}], ",", 
     "derangementCirc"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"DrawDerangementCircuit", "[", 
  RowBox[{"fullCirc", ",", "numQs", ",", "2"}], "]"}]}], "Input",
 CellChangeTimes->{{3.827241121838567*^9, 3.8272411534472647`*^9}},
 CellLabel->"In[27]:=",ExpressionUUID->"c62638dd-14d4-43e8-bb4e-97cea1b529fc"],

Cell[BoxData[
 GraphicsBox[
  {EdgeForm[GrayLevel[0]], FaceForm[GrayLevel[
   1]], {{LineBox[{{0, 0.5}, {1, 0.5}}], LineBox[{{0, 1.5}, {1, 1.5}}], 
     LineBox[{{0, 2.5}, {1, 2.5}}], LineBox[{{0, 3.5}, {1, 3.5}}], 
     LineBox[{{0, 4.5}, {1, 4.5}}], LineBox[{{0, 5.5}, {1, 5.5}}], 
     LineBox[{{0, 6.5}, {1, 6.5}}], LineBox[{{0, 7.5}, {1, 7.5}}], 
     LineBox[{{0, 8.5}, {1, 8.5}}], LineBox[{{0, 9.5}, {1, 9.5}}], 
     LineBox[{{0, 10.5}, {1, 10.5}}]}, {LineBox[{{1, 0.5}, {2, 0.5}}], 
     LineBox[{{1, 1.5}, {2, 1.5}}], LineBox[{{1, 2.5}, {2, 2.5}}], 
     LineBox[{{1, 3.5}, {2, 3.5}}], LineBox[{{1, 4.5}, {2, 4.5}}], 
     LineBox[{{1, 5.5}, {2, 5.5}}], LineBox[{{1, 6.5}, {2, 6.5}}], 
     LineBox[{{1, 7.5}, {2, 7.5}}], LineBox[{{1, 8.5}, {2, 8.5}}], 
     LineBox[{{1, 9.5}, {2, 9.5}}], LineBox[{{1, 10.5}, {2, 10.5}}]}, {
     LineBox[{{2, 0.5}, {3, 0.5}}], LineBox[{{2, 1.5}, {3, 1.5}}], 
     LineBox[{{2, 2.5}, {3, 2.5}}], LineBox[{{2, 3.5}, {3, 3.5}}], 
     LineBox[{{2, 4.5}, {3, 4.5}}], LineBox[{{2, 5.5}, {3, 5.5}}], 
     LineBox[{{2, 6.5}, {3, 6.5}}], LineBox[{{2, 7.5}, {3, 7.5}}], 
     LineBox[{{2, 8.5}, {3, 8.5}}], LineBox[{{2, 9.5}, {3, 9.5}}], 
     LineBox[{{2, 10.5}, {3, 10.5}}]}, {LineBox[{{3, 0.5}, {4, 0.5}}], 
     LineBox[{{3, 1.5}, {4, 1.5}}], LineBox[{{3, 2.5}, {4, 2.5}}], 
     LineBox[{{3, 3.5}, {4, 3.5}}], LineBox[{{3, 4.5}, {4, 4.5}}], 
     LineBox[{{3, 5.5}, {4, 5.5}}], LineBox[{{3, 6.5}, {4, 6.5}}], 
     LineBox[{{3, 7.5}, {4, 7.5}}], LineBox[{{3, 8.5}, {4, 8.5}}], 
     LineBox[{{3, 9.5}, {4, 9.5}}], LineBox[{{3, 10.5}, {4, 10.5}}]}, {
     LineBox[{{4, 0.5}, {5, 0.5}}], LineBox[{{4, 1.5}, {5, 1.5}}], 
     LineBox[{{4, 2.5}, {5, 2.5}}], LineBox[{{4, 3.5}, {5, 3.5}}], 
     LineBox[{{4, 4.5}, {5, 4.5}}], LineBox[{{4, 5.5}, {5, 5.5}}], 
     LineBox[{{4, 6.5}, {5, 6.5}}], LineBox[{{4, 7.5}, {5, 7.5}}], 
     LineBox[{{4, 8.5}, {5, 8.5}}], LineBox[{{4, 9.5}, {5, 9.5}}], 
     LineBox[{{4, 10.5}, {5, 10.5}}]}, {LineBox[{{5, 0.5}, {6, 0.5}}], 
     LineBox[{{5, 1.5}, {6, 1.5}}], LineBox[{{5, 2.5}, {6, 2.5}}], 
     LineBox[{{5, 3.5}, {6, 3.5}}], LineBox[{{5, 4.5}, {6, 4.5}}], 
     LineBox[{{5, 5.5}, {6, 5.5}}], LineBox[{{5, 6.5}, {6, 6.5}}], 
     LineBox[{{5, 7.5}, {6, 7.5}}], LineBox[{{5, 8.5}, {6, 8.5}}], 
     LineBox[{{5, 9.5}, {6, 9.5}}], LineBox[{{5, 10.5}, {6, 10.5}}]}, {
     LineBox[{{6, 0.5}, {7, 0.5}}], LineBox[{{6, 1.5}, {7, 1.5}}], 
     LineBox[{{6, 2.5}, {7, 2.5}}], LineBox[{{6, 3.5}, {7, 3.5}}], 
     LineBox[{{6, 4.5}, {7, 4.5}}], LineBox[{{6, 5.5}, {7, 5.5}}], 
     LineBox[{{6, 6.5}, {7, 6.5}}], LineBox[{{6, 7.5}, {7, 7.5}}], 
     LineBox[{{6, 8.5}, {7, 8.5}}], LineBox[{{6, 9.5}, {7, 9.5}}], 
     LineBox[{{6, 10.5}, {7, 10.5}}]}, {LineBox[{{7, 0.5}, {8, 0.5}}], 
     LineBox[{{7, 1.5}, {8, 1.5}}], LineBox[{{7, 2.5}, {8, 2.5}}], 
     LineBox[{{7, 3.5}, {8, 3.5}}], LineBox[{{7, 4.5}, {8, 4.5}}], 
     LineBox[{{7, 5.5}, {8, 5.5}}], LineBox[{{7, 6.5}, {8, 6.5}}], 
     LineBox[{{7, 7.5}, {8, 7.5}}], LineBox[{{7, 8.5}, {8, 8.5}}], 
     LineBox[{{7, 9.5}, {8, 9.5}}], LineBox[{{7, 10.5}, {8, 10.5}}]}, {
     LineBox[{{8, 0.5}, {9, 0.5}}], LineBox[{{8, 1.5}, {9, 1.5}}], 
     LineBox[{{8, 2.5}, {9, 2.5}}], LineBox[{{8, 3.5}, {9, 3.5}}], 
     LineBox[{{8, 4.5}, {9, 4.5}}], LineBox[{{8, 5.5}, {9, 5.5}}], 
     LineBox[{{8, 6.5}, {9, 6.5}}], LineBox[{{8, 7.5}, {9, 7.5}}], 
     LineBox[{{8, 8.5}, {9, 8.5}}], LineBox[{{8, 9.5}, {9, 9.5}}], 
     LineBox[{{8, 10.5}, {9, 10.5}}]}, {LineBox[{{9, 0.5}, {10, 0.5}}], 
     LineBox[{{9, 1.5}, {10, 1.5}}], LineBox[{{9, 2.5}, {10, 2.5}}], 
     LineBox[{{9, 3.5}, {10, 3.5}}], LineBox[{{9, 4.5}, {10, 4.5}}], 
     LineBox[{{9, 5.5}, {10, 5.5}}], LineBox[{{9, 6.5}, {10, 6.5}}], 
     LineBox[{{9, 7.5}, {10, 7.5}}], LineBox[{{9, 8.5}, {10, 8.5}}], 
     LineBox[{{9, 9.5}, {10, 9.5}}], LineBox[{{9, 10.5}, {10, 10.5}}]}, {
     LineBox[{{10, 0.5}, {11, 0.5}}], LineBox[{{10, 1.5}, {11, 1.5}}], 
     LineBox[{{10, 2.5}, {11, 2.5}}], LineBox[{{10, 3.5}, {11, 3.5}}], 
     LineBox[{{10, 4.5}, {11, 4.5}}], LineBox[{{10, 5.5}, {11, 5.5}}], 
     LineBox[{{10, 6.5}, {11, 6.5}}], LineBox[{{10, 7.5}, {11, 7.5}}], 
     LineBox[{{10, 8.5}, {11, 8.5}}], LineBox[{{10, 9.5}, {11, 9.5}}], 
     LineBox[{{10, 10.5}, {11, 10.5}}]}, {LineBox[{{11, 0.5}, {12, 0.5}}], 
     LineBox[{{11, 1.5}, {12, 1.5}}], LineBox[{{11, 2.5}, {12, 2.5}}], 
     LineBox[{{11, 3.5}, {12, 3.5}}], LineBox[{{11, 4.5}, {12, 4.5}}], 
     LineBox[{{11, 5.5}, {12, 5.5}}], LineBox[{{11, 6.5}, {12, 6.5}}], 
     LineBox[{{11, 7.5}, {12, 7.5}}], LineBox[{{11, 8.5}, {12, 8.5}}], 
     LineBox[{{11, 9.5}, {12, 9.5}}], LineBox[{{11, 10.5}, {12, 10.5}}]}, {
     LineBox[{{12, 0.5}, {13, 0.5}}], LineBox[{{12, 1.5}, {13, 1.5}}], 
     LineBox[{{12, 2.5}, {13, 2.5}}], LineBox[{{12, 3.5}, {13, 3.5}}], 
     LineBox[{{12, 4.5}, {13, 4.5}}], LineBox[{{12, 5.5}, {13, 5.5}}], 
     LineBox[{{12, 6.5}, {13, 6.5}}], LineBox[{{12, 7.5}, {13, 7.5}}], 
     LineBox[{{12, 8.5}, {13, 8.5}}], LineBox[{{12, 9.5}, {13, 9.5}}], 
     LineBox[{{12, 10.5}, {13, 10.5}}]}, {LineBox[{{13, 0.5}, {14, 0.5}}], 
     LineBox[{{13, 1.5}, {14, 1.5}}], LineBox[{{13, 2.5}, {14, 2.5}}], 
     LineBox[{{13, 3.5}, {14, 3.5}}], LineBox[{{13, 4.5}, {14, 4.5}}], 
     LineBox[{{13, 5.5}, {14, 5.5}}], LineBox[{{13, 6.5}, {14, 6.5}}], 
     LineBox[{{13, 7.5}, {14, 7.5}}], LineBox[{{13, 8.5}, {14, 8.5}}], 
     LineBox[{{13, 9.5}, {14, 9.5}}], LineBox[{{13, 10.5}, {14, 10.5}}]}, {
     LineBox[{{14, 0.5}, {15, 0.5}}], LineBox[{{14, 1.5}, {15, 1.5}}], 
     LineBox[{{14, 2.5}, {15, 2.5}}], LineBox[{{14, 3.5}, {15, 3.5}}], 
     LineBox[{{14, 4.5}, {15, 4.5}}], LineBox[{{14, 5.5}, {15, 5.5}}], 
     LineBox[{{14, 6.5}, {15, 6.5}}], LineBox[{{14, 7.5}, {15, 7.5}}], 
     LineBox[{{14, 8.5}, {15, 8.5}}], LineBox[{{14, 9.5}, {15, 9.5}}], 
     LineBox[{{14, 10.5}, {15, 10.5}}]}, {LineBox[{{15, 0.5}, {16, 0.5}}], 
     LineBox[{{15, 1.5}, {16, 1.5}}], LineBox[{{15, 2.5}, {16, 2.5}}], 
     LineBox[{{15, 3.5}, {16, 3.5}}], LineBox[{{15, 4.5}, {16, 4.5}}], 
     LineBox[{{15, 5.5}, {16, 5.5}}], LineBox[{{15, 6.5}, {16, 6.5}}], 
     LineBox[{{15, 7.5}, {16, 7.5}}], LineBox[{{15, 8.5}, {16, 8.5}}], 
     LineBox[{{15, 9.5}, {16, 9.5}}], LineBox[{{15, 10.5}, {16, 10.5}}]}, {
     LineBox[{{16, 0.5}, {17, 0.5}}], LineBox[{{16, 1.5}, {17, 1.5}}], 
     LineBox[{{16, 2.5}, {17, 2.5}}], LineBox[{{16, 3.5}, {17, 3.5}}], 
     LineBox[{{16, 4.5}, {17, 4.5}}], LineBox[{{16, 5.5}, {17, 5.5}}], 
     LineBox[{{16, 6.5}, {17, 6.5}}], LineBox[{{16, 7.5}, {17, 7.5}}], 
     LineBox[{{16, 8.5}, {17, 8.5}}], LineBox[{{16, 9.5}, {17, 9.5}}], 
     LineBox[{{16, 10.5}, {17, 10.5}}]}, {LineBox[{{17, 0.5}, {18, 0.5}}], 
     LineBox[{{17, 1.5}, {18, 1.5}}], LineBox[{{17, 2.5}, {18, 2.5}}], 
     LineBox[{{17, 3.5}, {18, 3.5}}], LineBox[{{17, 4.5}, {18, 4.5}}], 
     LineBox[{{17, 5.5}, {18, 5.5}}], LineBox[{{17, 6.5}, {18, 6.5}}], 
     LineBox[{{17, 7.5}, {18, 7.5}}], LineBox[{{17, 8.5}, {18, 8.5}}], 
     LineBox[{{17, 9.5}, {18, 9.5}}], LineBox[{{17, 10.5}, {18, 10.5}}]}, {
     LineBox[{{18, 0.5}, {19, 0.5}}], LineBox[{{18, 1.5}, {19, 1.5}}], 
     LineBox[{{18, 2.5}, {19, 2.5}}], LineBox[{{18, 3.5}, {19, 3.5}}], 
     LineBox[{{18, 4.5}, {19, 4.5}}], LineBox[{{18, 5.5}, {19, 5.5}}], 
     LineBox[{{18, 6.5}, {19, 6.5}}], LineBox[{{18, 7.5}, {19, 7.5}}], 
     LineBox[{{18, 8.5}, {19, 8.5}}], LineBox[{{18, 9.5}, {19, 9.5}}], 
     LineBox[{{18, 10.5}, {19, 10.5}}]}, {LineBox[{{19, 0.5}, {20, 0.5}}], 
     LineBox[{{19, 1.5}, {20, 1.5}}], LineBox[{{19, 2.5}, {20, 2.5}}], 
     LineBox[{{19, 3.5}, {20, 3.5}}], LineBox[{{19, 4.5}, {20, 4.5}}], 
     LineBox[{{19, 5.5}, {20, 5.5}}], LineBox[{{19, 6.5}, {20, 6.5}}], 
     LineBox[{{19, 7.5}, {20, 7.5}}], LineBox[{{19, 8.5}, {20, 8.5}}], 
     LineBox[{{19, 9.5}, {20, 9.5}}], LineBox[{{19, 10.5}, {20, 10.5}}]}, {
     LineBox[{{20, 0.5}, {21, 0.5}}], LineBox[{{20, 1.5}, {21, 1.5}}], 
     LineBox[{{20, 2.5}, {21, 2.5}}], LineBox[{{20, 3.5}, {21, 3.5}}], 
     LineBox[{{20, 4.5}, {21, 4.5}}], LineBox[{{20, 5.5}, {21, 5.5}}], 
     LineBox[{{20, 6.5}, {21, 6.5}}], LineBox[{{20, 7.5}, {21, 7.5}}], 
     LineBox[{{20, 8.5}, {21, 8.5}}], LineBox[{{20, 9.5}, {21, 9.5}}], 
     LineBox[{{20, 10.5}, {21, 10.5}}]}, {LineBox[{{21, 0.5}, {22, 0.5}}], 
     LineBox[{{21, 1.5}, {22, 1.5}}], LineBox[{{21, 2.5}, {22, 2.5}}], 
     LineBox[{{21, 3.5}, {22, 3.5}}], LineBox[{{21, 4.5}, {22, 4.5}}], 
     LineBox[{{21, 5.5}, {22, 5.5}}], LineBox[{{21, 6.5}, {22, 6.5}}], 
     LineBox[{{21, 7.5}, {22, 7.5}}], LineBox[{{21, 8.5}, {22, 8.5}}], 
     LineBox[{{21, 9.5}, {22, 9.5}}], LineBox[{{21, 10.5}, {22, 10.5}}]}, {
     LineBox[{{22, 0.5}, {23, 0.5}}], LineBox[{{22, 1.5}, {23, 1.5}}], 
     LineBox[{{22, 2.5}, {23, 2.5}}], LineBox[{{22, 3.5}, {23, 3.5}}], 
     LineBox[{{22, 4.5}, {23, 4.5}}], LineBox[{{22, 5.5}, {23, 5.5}}], 
     LineBox[{{22, 6.5}, {23, 6.5}}], LineBox[{{22, 7.5}, {23, 7.5}}], 
     LineBox[{{22, 8.5}, {23, 8.5}}], LineBox[{{22, 9.5}, {23, 9.5}}], 
     LineBox[{{22, 10.5}, {23, 10.5}}]}, {LineBox[{{23, 0.5}, {24, 0.5}}], 
     LineBox[{{23, 1.5}, {24, 1.5}}], LineBox[{{23, 2.5}, {24, 2.5}}], 
     LineBox[{{23, 3.5}, {24, 3.5}}], LineBox[{{23, 4.5}, {24, 4.5}}], 
     LineBox[{{23, 5.5}, {24, 5.5}}], LineBox[{{23, 6.5}, {24, 6.5}}], 
     LineBox[{{23, 7.5}, {24, 7.5}}], LineBox[{{23, 8.5}, {24, 8.5}}], 
     LineBox[{{23, 9.5}, {24, 9.5}}], LineBox[{{23, 10.5}, {24, 10.5}}]}, {
     LineBox[{{24, 0.5}, {25, 0.5}}], LineBox[{{24, 1.5}, {25, 1.5}}], 
     LineBox[{{24, 2.5}, {25, 2.5}}], LineBox[{{24, 3.5}, {25, 3.5}}], 
     LineBox[{{24, 4.5}, {25, 4.5}}], LineBox[{{24, 5.5}, {25, 5.5}}], 
     LineBox[{{24, 6.5}, {25, 6.5}}], LineBox[{{24, 7.5}, {25, 7.5}}], 
     LineBox[{{24, 8.5}, {25, 8.5}}], LineBox[{{24, 9.5}, {25, 9.5}}], 
     LineBox[{{24, 10.5}, {25, 10.5}}]}, {LineBox[{{25, 0.5}, {26, 0.5}}], 
     LineBox[{{25, 1.5}, {26, 1.5}}], LineBox[{{25, 2.5}, {26, 2.5}}], 
     LineBox[{{25, 3.5}, {26, 3.5}}], LineBox[{{25, 4.5}, {26, 4.5}}], 
     LineBox[{{25, 5.5}, {26, 5.5}}], LineBox[{{25, 6.5}, {26, 6.5}}], 
     LineBox[{{25, 7.5}, {26, 7.5}}], LineBox[{{25, 8.5}, {26, 8.5}}], 
     LineBox[{{25, 9.5}, {26, 9.5}}], LineBox[{{25, 10.5}, {26, 10.5}}]}, {
     LineBox[{{26, 0.5}, {27, 0.5}}], LineBox[{{26, 1.5}, {27, 1.5}}], 
     LineBox[{{26, 2.5}, {27, 2.5}}], LineBox[{{26, 3.5}, {27, 3.5}}], 
     LineBox[{{26, 4.5}, {27, 4.5}}], LineBox[{{26, 5.5}, {27, 5.5}}], 
     LineBox[{{26, 6.5}, {27, 6.5}}], LineBox[{{26, 7.5}, {27, 7.5}}], 
     LineBox[{{26, 8.5}, {27, 8.5}}], LineBox[{{26, 9.5}, {27, 9.5}}], 
     LineBox[{{26, 10.5}, {27, 10.5}}]}, {LineBox[{{27, 0.5}, {28, 0.5}}], 
     LineBox[{{27, 1.5}, {28, 1.5}}], LineBox[{{27, 2.5}, {28, 2.5}}], 
     LineBox[{{27, 3.5}, {28, 3.5}}], LineBox[{{27, 4.5}, {28, 4.5}}], 
     LineBox[{{27, 5.5}, {28, 5.5}}], LineBox[{{27, 6.5}, {28, 6.5}}], 
     LineBox[{{27, 7.5}, {28, 7.5}}], LineBox[{{27, 8.5}, {28, 8.5}}], 
     LineBox[{{27, 9.5}, {28, 9.5}}], LineBox[{{27, 10.5}, {28, 10.5}}]}}, {{
     RectangleBox[{0.1, 4.1}, {0.9, 4.9}], 
     InsetBox["\<\"H\"\>", {0.5, 4.5}]}, {
     {FaceForm[GrayLevel[0]], DiskBox[{1.5, 4.5}, 0.1], 
      LineBox[{{1.5, 3.5}, {1.5, 4.5}}]}, {CircleBox[{1.5, 3.5}, 0.25], 
      LineBox[{{1.5, 3.25}, {1.5, 3.75}}]}}, 
    {EdgeForm[Dashing[{Small, Small}]], RectangleBox[{2.1, 3.1}, {2.9, 4.9}], 
     InsetBox["\<\"\[CapitalDelta]\"\>", {2.5, 4.}]}, {
     {FaceForm[GrayLevel[0]], DiskBox[{3.5, 3.5}, 0.1], 
      LineBox[{{3.5, 2.5}, {3.5, 3.5}}]}, {CircleBox[{3.5, 2.5}, 0.25], 
      LineBox[{{3.5, 2.25}, {3.5, 2.75}}]}}, 
    {EdgeForm[Dashing[{Small, Small}]], RectangleBox[{4.1, 2.1}, {4.9, 3.9}], 
     InsetBox["\<\"\[CapitalDelta]\"\>", {4.5, 3.}]}, {
     {FaceForm[GrayLevel[0]], DiskBox[{5.5, 2.5}, 0.1], 
      LineBox[{{5.5, 1.5}, {5.5, 2.5}}]}, {CircleBox[{5.5, 1.5}, 0.25], 
      LineBox[{{5.5, 1.25}, {5.5, 1.75}}]}}, 
    {EdgeForm[Dashing[{Small, Small}]], RectangleBox[{6.1, 1.1}, {6.9, 2.9}], 
     InsetBox["\<\"\[CapitalDelta]\"\>", {6.5, 2.}]}, {
     {FaceForm[GrayLevel[0]], DiskBox[{7.5, 1.5}, 0.1], 
      LineBox[{{7.5, 0.5}, {7.5, 1.5}}]}, {CircleBox[{7.5, 0.5}, 0.25], 
      LineBox[{{7.5, 0.25}, {7.5, 0.75}}]}}, 
    {EdgeForm[Dashing[{Small, Small}]], RectangleBox[{8.1, 0.1}, {8.9, 1.9}], 
     InsetBox["\<\"\[CapitalDelta]\"\>", {8.5, 1.}]}, {
     RectangleBox[{8.1, 9.1}, {8.9, 9.9}], 
     InsetBox["\<\"H\"\>", {8.5, 9.5}]}, {
     {FaceForm[GrayLevel[0]], DiskBox[{9.5, 9.5}, 0.1], 
      LineBox[{{9.5, 8.5}, {9.5, 9.5}}]}, {CircleBox[{9.5, 8.5}, 0.25], 
      LineBox[{{9.5, 8.25}, {9.5, 8.75}}]}}, 
    {EdgeForm[Dashing[{Small, Small}]], 
     RectangleBox[{10.1, 8.1}, {10.9, 9.9}], 
     InsetBox["\<\"\[CapitalDelta]\"\>", {10.5, 9.}]}, {
     {FaceForm[GrayLevel[0]], DiskBox[{11.5, 8.5}, 0.1], 
      LineBox[{{11.5, 7.5}, {11.5, 8.5}}]}, {CircleBox[{11.5, 7.5}, 0.25], 
      LineBox[{{11.5, 7.25}, {11.5, 7.75}}]}}, 
    {EdgeForm[Dashing[{Small, Small}]], 
     RectangleBox[{12.1, 7.1}, {12.9, 8.9}], 
     InsetBox["\<\"\[CapitalDelta]\"\>", {12.5, 8.}]}, {
     {FaceForm[GrayLevel[0]], DiskBox[{13.5, 7.5}, 0.1], 
      LineBox[{{13.5, 6.5}, {13.5, 7.5}}]}, {CircleBox[{13.5, 6.5}, 0.25], 
      LineBox[{{13.5, 6.25}, {13.5, 6.75}}]}}, 
    {EdgeForm[Dashing[{Small, Small}]], 
     RectangleBox[{14.1, 6.1}, {14.9, 7.9}], 
     InsetBox["\<\"\[CapitalDelta]\"\>", {14.5, 7.}]}, {
     {FaceForm[GrayLevel[0]], DiskBox[{15.5, 6.5}, 0.1], 
      LineBox[{{15.5, 5.5}, {15.5, 6.5}}]}, {CircleBox[{15.5, 5.5}, 0.25], 
      LineBox[{{15.5, 5.25}, {15.5, 5.75}}]}}, 
    {EdgeForm[Dashing[{Small, Small}]], 
     RectangleBox[{16.1, 5.1}, {16.9, 6.9}], 
     InsetBox["\<\"\[CapitalDelta]\"\>", {16.5, 6.}]}, {
     RectangleBox[{16.1, 10.1}, {16.9, 10.9}], 
     InsetBox["\<\"H\"\>", {16.5, 10.5}]}, {
     {FaceForm[GrayLevel[0]], DiskBox[{17.5, 10.5}, 0.1], 
      LineBox[{{17.5, 0.5}, {17.5, 
       10.5}}]}, {{{LineBox[{{17.4, 0.4}, {17.6, 0.6}}], 
        LineBox[{{17.6, 0.4}, {17.4, 0.6}}]}, {
        LineBox[{{17.4, 5.4}, {17.6, 5.6}}], 
        LineBox[{{17.6, 5.4}, {17.4, 5.6}}]}}, 
      LineBox[{{17.5, 0.5}, {17.5, 5.5}}]}}, {
     {FaceForm[GrayLevel[0]], DiskBox[{18.5, 10.5}, 0.1], 
      LineBox[{{18.5, 1.5}, {18.5, 
       10.5}}]}, {{{LineBox[{{18.4, 1.4}, {18.6, 1.6}}], 
        LineBox[{{18.6, 1.4}, {18.4, 1.6}}]}, {
        LineBox[{{18.4, 6.4}, {18.6, 6.6}}], 
        LineBox[{{18.6, 6.4}, {18.4, 6.6}}]}}, 
      LineBox[{{18.5, 1.5}, {18.5, 6.5}}]}}, {
     {FaceForm[GrayLevel[0]], DiskBox[{19.5, 10.5}, 0.1], 
      LineBox[{{19.5, 2.5}, {19.5, 
       10.5}}]}, {{{LineBox[{{19.4, 2.4}, {19.6, 2.6}}], 
        LineBox[{{19.6, 2.4}, {19.4, 2.6}}]}, {
        LineBox[{{19.4, 7.4}, {19.6, 7.6}}], 
        LineBox[{{19.6, 7.4}, {19.4, 7.6}}]}}, 
      LineBox[{{19.5, 2.5}, {19.5, 7.5}}]}}, {
     {FaceForm[GrayLevel[0]], DiskBox[{20.5, 10.5}, 0.1], 
      LineBox[{{20.5, 3.5}, {20.5, 
       10.5}}]}, {{{LineBox[{{20.4, 3.4}, {20.6, 3.6}}], 
        LineBox[{{20.6, 3.4}, {20.4, 3.6}}]}, {
        LineBox[{{20.4, 8.4}, {20.6, 8.6}}], 
        LineBox[{{20.6, 8.4}, {20.4, 8.6}}]}}, 
      LineBox[{{20.5, 3.5}, {20.5, 8.5}}]}}, {
     {FaceForm[GrayLevel[0]], DiskBox[{21.5, 10.5}, 0.1], 
      LineBox[{{21.5, 4.5}, {21.5, 
       10.5}}]}, {{{LineBox[{{21.4, 4.4}, {21.6, 4.6}}], 
        LineBox[{{21.6, 4.4}, {21.4, 4.6}}]}, {
        LineBox[{{21.4, 9.4}, {21.6, 9.6}}], 
        LineBox[{{21.6, 9.4}, {21.4, 9.6}}]}}, 
      LineBox[{{21.5, 4.5}, {21.5, 9.5}}]}}, {
     {FaceForm[GrayLevel[0]], DiskBox[{22.5, 10.5}, 0.1], 
      LineBox[{{22.5, 5.5}, {22.5, 10.5}}]}, {CircleBox[{22.5, 5.5}, 0.25], 
      LineBox[{{22.5, 5.25}, {22.5, 5.75}}]}}, {
     {FaceForm[GrayLevel[0]], DiskBox[{23.5, 10.5}, 0.1], 
      LineBox[{{23.5, 6.5}, {23.5, 10.5}}]}, {CircleBox[{23.5, 6.5}, 0.25], 
      LineBox[{{23.5, 6.25}, {23.5, 6.75}}]}}, {
     {FaceForm[GrayLevel[0]], DiskBox[{24.5, 10.5}, 0.1], 
      LineBox[{{24.5, 7.5}, {24.5, 10.5}}]}, {CircleBox[{24.5, 7.5}, 0.25], 
      LineBox[{{24.5, 7.25}, {24.5, 7.75}}]}}, {
     {FaceForm[GrayLevel[0]], DiskBox[{25.5, 10.5}, 0.1], 
      LineBox[{{25.5, 8.5}, {25.5, 10.5}}]}, {CircleBox[{25.5, 8.5}, 0.25], 
      LineBox[{{25.5, 8.25}, {25.5, 8.75}}]}}, {
     {FaceForm[GrayLevel[0]], DiskBox[{26.5, 10.5}, 0.1], 
      LineBox[{{26.5, 9.5}, {26.5, 10.5}}]}, {CircleBox[{26.5, 9.5}, 0.25], 
      LineBox[{{26.5, 9.25}, {26.5, 9.75}}]}}, {
     RectangleBox[{27.1, 10.1}, {27.9, 10.9}], 
     InsetBox["\<\"H\"\>", {27.5, 10.5}]}}},
  Epilog->{
    FaceForm[None], 
    EdgeForm[
     Directive[
      RGBColor[1, 0, 0], 
      Dashing[{Small, Small}]]], 
    InsetBox[
     FormBox[
      StyleBox[
       InterpretationBox[
       "\"Reg. \\!\\(\\*FormBox[\\\"0\\\", TraditionalForm]\\)\"", 
        StringForm["Reg. ``", 0], Editable -> False], FontSize -> 12, 
       StripOnInput -> False], TraditionalForm], {0, 0.4}, {-1, -1}], 
    EdgeForm[
     Directive[
      RGBColor[1, 0, 0], 
      Dashing[{Small, Small}], 
      Opacity[0.4]]], 
    RectangleBox[{0, 0.2}, {30, 4.8}], 
    InsetBox[
     FormBox[
      StyleBox[
       InterpretationBox[
       "\"Reg. \\!\\(\\*FormBox[\\\"1\\\", TraditionalForm]\\)\"", 
        StringForm["Reg. ``", 1], Editable -> False], FontSize -> 12, 
       StripOnInput -> False], TraditionalForm], {0, 5.4}, {-1, -1}], 
    EdgeForm[
     Directive[
      RGBColor[0, 0, 1], 
      Dashing[{Small, Small}], 
      Opacity[0.4]]], 
    RectangleBox[{0, 5.2}, {30, 9.8}]},
  ImageSize->840,
  Method->{"ShrinkWrap" -> True}]], "Output",
 CellChangeTimes->{{3.827241150360924*^9, 3.8272411541388273`*^9}, 
   3.8272413484035535`*^9, 3.8272414168690968`*^9, 3.8272425495680227`*^9, 
   3.8272428273230047`*^9},
 CellLabel->"Out[29]=",ExpressionUUID->"e32eb7a6-39ae-4a39-894e-f7f5079b1b59"]
}, Open  ]],

Cell[TextData[{
 "Simulate the circuit in QuESTlink and compute the probability on the \
ancilla qubit ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"as", " ", 
     SubscriptBox["prob", "0"]}], "="}], TraditionalForm]],ExpressionUUID->
  "9ba89c44-3def-4b6a-a5f2-ede7b353015d"],
 Cell[BoxData[
  FormBox[
   RowBox[{"Tr", "[", 
    SuperscriptBox["\[Rho]", "2"]}], TraditionalForm]],ExpressionUUID->
  "0e022273-78e5-4a56-b353-f5b2502947b3"],
 "  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["X", "0"], " ", 
   SubscriptBox["X", "1"], " ", 
   SubscriptBox["X", "2"], " ", 
   SubscriptBox["X", "3"], " ", 
   SubscriptBox["X", "4"]}]],
  CellChangeTimes->{{3.8272398338718214`*^9, 3.827239840139904*^9}},
  ExpressionUUID->"531adda4-e38b-45c5-abe8-ba8908d46e3c"],
 "]"
}], "Text",
 CellChangeTimes->{{3.8262650902861843`*^9, 3.826265091099492*^9}, {
   3.8262652312441196`*^9, 3.826265473334661*^9}, {3.8264936657315893`*^9, 
   3.826493710958598*^9}, {3.826493827200305*^9, 3.8264938282809477`*^9}, {
   3.8264939742007303`*^9, 3.82649405518382*^9}, {3.8272392140975666`*^9, 
   3.827239224966739*^9}, {3.827239268488271*^9, 3.8272392931488256`*^9}, {
   3.827239343424307*^9, 3.8272393559192715`*^9}, {3.8272395839220505`*^9, 
   3.827239589466489*^9}, {3.827240071375389*^9, 3.8272400906643705`*^9}, {
   3.8272401554151773`*^9, 3.8272401678247633`*^9}, {3.8272402594347553`*^9, 
   3.827240276773361*^9}, {3.8272403088310623`*^9, 3.8272404918762016`*^9}, {
   3.8272407721152735`*^9, 3.8272407728647995`*^9}, {3.827240808213707*^9, 
   3.827240831829824*^9}, 3.8272409247161636`*^9, {3.82724109514158*^9, 
   3.8272411110757155`*^9}, {3.8272411752391224`*^9, 3.82724122372865*^9}, {
   3.827241897225638*^9, 3.827242017278228*^9}, {3.8272442893313437`*^9, 
   3.827244289513113*^9}},
 Background->RGBColor[
  0.88, 1, 0.88],ExpressionUUID->"afe72775-5f82-4006-b1f2-f4aa6fd7e2c3"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Rho]", "=", 
   RowBox[{"CreateDensityQureg", "[", "totNumQ", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ApplyCircuit", "[", 
   RowBox[{"fullCirc", ",", 
    RowBox[{"InitZeroState", "@", "\[Rho]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"prob0", "=", 
   RowBox[{
    RowBox[{"2", 
     RowBox[{"CalcProbOfOutcome", "[", 
      RowBox[{"\[Rho]", ",", 
       RowBox[{"2", "*", "numQs"}], ",", "0"}], "]"}]}], "-", "1"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{
  3.827241893400132*^9, {3.827241933010459*^9, 3.8272419369095817`*^9}, {
   3.8272420203748856`*^9, 3.827242021474516*^9}},
 CellLabel->"In[30]:=",ExpressionUUID->"37f1dc96-13e9-449a-9660-cc93409819df"],

Cell["\<\
Set up the circuit that measures the expectation value of the identity \
operator (required by the ESD/VD technique for correct normalisation)\
\>", "Text",
 CellChangeTimes->{{3.8262650902861843`*^9, 3.826265091099492*^9}, {
   3.8262652312441196`*^9, 3.826265473334661*^9}, {3.8264936657315893`*^9, 
   3.826493710958598*^9}, {3.826493827200305*^9, 3.8264938282809477`*^9}, {
   3.8264939742007303`*^9, 3.82649405518382*^9}, {3.8272392140975666`*^9, 
   3.827239224966739*^9}, {3.827239268488271*^9, 3.8272392931488256`*^9}, {
   3.827239343424307*^9, 3.8272393559192715`*^9}, {3.8272395839220505`*^9, 
   3.827239589466489*^9}, {3.827240071375389*^9, 3.8272400906643705`*^9}, {
   3.8272401554151773`*^9, 3.8272401678247633`*^9}, {3.8272402594347553`*^9, 
   3.827240276773361*^9}, {3.8272403088310623`*^9, 3.8272404918762016`*^9}, {
   3.8272407721152735`*^9, 3.8272407728647995`*^9}, {3.827240808213707*^9, 
   3.827240831829824*^9}, 3.8272409247161636`*^9, {3.82724109514158*^9, 
   3.8272411110757155`*^9}, {3.8272411752391224`*^9, 3.82724122372865*^9}},
 Background->RGBColor[
  0.88, 1, 0.88],ExpressionUUID->"65b9a174-57ae-4a9d-aecb-7ded2ef16b60"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"derangementCircId", "=", 
   RowBox[{"D2", "[", 
    RowBox[{"numQs", ",", 
     SubscriptBox["Id", "0"]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fullCircId", "=", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"CopiesOfCircuit", "[", 
      RowBox[{"noisyGHZcirc", ",", "2", ",", "numQs"}], "]"}], ",", 
     "derangementCircId"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"DrawDerangementCircuit", "[", 
  RowBox[{"fullCircId", ",", "numQs", ",", "2"}], "]"}]}], "Input",
 CellChangeTimes->{{3.8260221893071127`*^9, 3.8260222825498495`*^9}, {
   3.826022469581562*^9, 3.8260224793649344`*^9}, {3.82602266522556*^9, 
   3.826022872518877*^9}, {3.826022910424039*^9, 3.8260229355516148`*^9}, {
   3.8260230157287035`*^9, 3.826023016590984*^9}, {3.826023061207801*^9, 
   3.826023249188407*^9}, {3.826025662328537*^9, 3.8260256627417865`*^9}, {
   3.8261766575433617`*^9, 3.8261766746370945`*^9}, {3.82687221409792*^9, 
   3.826872298944437*^9}, {3.826872445536232*^9, 3.826872502337929*^9}, {
   3.826875424212309*^9, 3.826875438519244*^9}, {3.826875474013958*^9, 
   3.8268756945917215`*^9}, {3.8268757375296392`*^9, 
   3.8268757926805105`*^9}, {3.8268759669650035`*^9, 
   3.8268759748505483`*^9}, {3.8268760062361517`*^9, 
   3.8268760110297503`*^9}, {3.826876048843635*^9, 3.8268760639415426`*^9}, {
   3.8268760950731826`*^9, 3.826876108676964*^9}, {3.826876139476552*^9, 
   3.826876188526916*^9}, {3.8268762922134504`*^9, 3.826876298421209*^9}, {
   3.8268763285460463`*^9, 3.826876415044627*^9}, {3.8268764645352354`*^9, 
   3.8268765126869345`*^9}, {3.8268767633496466`*^9, 3.826876767015259*^9}, {
   3.826877054815946*^9, 3.826877182333853*^9}, {3.826877434315336*^9, 
   3.826877642039488*^9}, {3.8268776761142864`*^9, 3.8268776778223376`*^9}, {
   3.8268777354507465`*^9, 3.826877753659024*^9}, {3.826877803061338*^9, 
   3.8268781013373165`*^9}, {3.82687815670776*^9, 3.8268781913222213`*^9}, {
   3.826878255480506*^9, 3.826878256230062*^9}, {3.8268782939854426`*^9, 
   3.8268784105487747`*^9}, {3.826878467393312*^9, 3.826878472315739*^9}, {
   3.8268785396075573`*^9, 3.8268785477423663`*^9}, {3.8268785971541195`*^9, 
   3.8268786408727407`*^9}, {3.826878726663971*^9, 3.8268787977741084`*^9}, {
   3.8268788427636986`*^9, 3.8268788428420963`*^9}, {3.8268789007429075`*^9, 
   3.8268789102054234`*^9}, {3.8268789935417876`*^9, 3.826878993639367*^9}, {
   3.8268866538873425`*^9, 3.8268866565472975`*^9}, {3.826887031413435*^9, 
   3.8268870319487658`*^9}, {3.826887068730373*^9, 3.82688706888705*^9}, {
   3.8268872985753403`*^9, 3.826887330476345*^9}, {3.8268875278843155`*^9, 
   3.8268875453908625`*^9}, {3.826887622827999*^9, 3.8268876570495176`*^9}, {
   3.8268942296195645`*^9, 3.826894237335995*^9}, {3.8268942735010242`*^9, 
   3.8268942789502306`*^9}, {3.8268963758222184`*^9, 3.826896395513639*^9}, {
   3.826897819333914*^9, 3.8268979814128637`*^9}, {3.82689804378118*^9, 
   3.826898066001677*^9}, {3.8268981004964657`*^9, 3.826898161176081*^9}, {
   3.826950115554283*^9, 3.8269501201390114`*^9}, {3.8269501562156963`*^9, 
   3.8269501961840415`*^9}, {3.8269502314598475`*^9, 
   3.8269502866840277`*^9}, {3.8269504054769135`*^9, 3.8269504193253684`*^9}, 
   3.827241167115308*^9, {3.8272412266642647`*^9, 3.8272412561201553`*^9}, {
   3.8272421150956383`*^9, 3.827242131017044*^9}},
 CellLabel->"In[33]:=",ExpressionUUID->"3bf20ede-d40f-479f-ac1a-c40499e5ea97"],

Cell[BoxData[
 GraphicsBox[
  {EdgeForm[GrayLevel[0]], FaceForm[GrayLevel[
   1]], {{LineBox[{{0, 0.5}, {1, 0.5}}], LineBox[{{0, 1.5}, {1, 1.5}}], 
     LineBox[{{0, 2.5}, {1, 2.5}}], LineBox[{{0, 3.5}, {1, 3.5}}], 
     LineBox[{{0, 4.5}, {1, 4.5}}], LineBox[{{0, 5.5}, {1, 5.5}}], 
     LineBox[{{0, 6.5}, {1, 6.5}}], LineBox[{{0, 7.5}, {1, 7.5}}], 
     LineBox[{{0, 8.5}, {1, 8.5}}], LineBox[{{0, 9.5}, {1, 9.5}}], 
     LineBox[{{0, 10.5}, {1, 10.5}}]}, {LineBox[{{1, 0.5}, {2, 0.5}}], 
     LineBox[{{1, 1.5}, {2, 1.5}}], LineBox[{{1, 2.5}, {2, 2.5}}], 
     LineBox[{{1, 3.5}, {2, 3.5}}], LineBox[{{1, 4.5}, {2, 4.5}}], 
     LineBox[{{1, 5.5}, {2, 5.5}}], LineBox[{{1, 6.5}, {2, 6.5}}], 
     LineBox[{{1, 7.5}, {2, 7.5}}], LineBox[{{1, 8.5}, {2, 8.5}}], 
     LineBox[{{1, 9.5}, {2, 9.5}}], LineBox[{{1, 10.5}, {2, 10.5}}]}, {
     LineBox[{{2, 0.5}, {3, 0.5}}], LineBox[{{2, 1.5}, {3, 1.5}}], 
     LineBox[{{2, 2.5}, {3, 2.5}}], LineBox[{{2, 3.5}, {3, 3.5}}], 
     LineBox[{{2, 4.5}, {3, 4.5}}], LineBox[{{2, 5.5}, {3, 5.5}}], 
     LineBox[{{2, 6.5}, {3, 6.5}}], LineBox[{{2, 7.5}, {3, 7.5}}], 
     LineBox[{{2, 8.5}, {3, 8.5}}], LineBox[{{2, 9.5}, {3, 9.5}}], 
     LineBox[{{2, 10.5}, {3, 10.5}}]}, {LineBox[{{3, 0.5}, {4, 0.5}}], 
     LineBox[{{3, 1.5}, {4, 1.5}}], LineBox[{{3, 2.5}, {4, 2.5}}], 
     LineBox[{{3, 3.5}, {4, 3.5}}], LineBox[{{3, 4.5}, {4, 4.5}}], 
     LineBox[{{3, 5.5}, {4, 5.5}}], LineBox[{{3, 6.5}, {4, 6.5}}], 
     LineBox[{{3, 7.5}, {4, 7.5}}], LineBox[{{3, 8.5}, {4, 8.5}}], 
     LineBox[{{3, 9.5}, {4, 9.5}}], LineBox[{{3, 10.5}, {4, 10.5}}]}, {
     LineBox[{{4, 0.5}, {5, 0.5}}], LineBox[{{4, 1.5}, {5, 1.5}}], 
     LineBox[{{4, 2.5}, {5, 2.5}}], LineBox[{{4, 3.5}, {5, 3.5}}], 
     LineBox[{{4, 4.5}, {5, 4.5}}], LineBox[{{4, 5.5}, {5, 5.5}}], 
     LineBox[{{4, 6.5}, {5, 6.5}}], LineBox[{{4, 7.5}, {5, 7.5}}], 
     LineBox[{{4, 8.5}, {5, 8.5}}], LineBox[{{4, 9.5}, {5, 9.5}}], 
     LineBox[{{4, 10.5}, {5, 10.5}}]}, {LineBox[{{5, 0.5}, {6, 0.5}}], 
     LineBox[{{5, 1.5}, {6, 1.5}}], LineBox[{{5, 2.5}, {6, 2.5}}], 
     LineBox[{{5, 3.5}, {6, 3.5}}], LineBox[{{5, 4.5}, {6, 4.5}}], 
     LineBox[{{5, 5.5}, {6, 5.5}}], LineBox[{{5, 6.5}, {6, 6.5}}], 
     LineBox[{{5, 7.5}, {6, 7.5}}], LineBox[{{5, 8.5}, {6, 8.5}}], 
     LineBox[{{5, 9.5}, {6, 9.5}}], LineBox[{{5, 10.5}, {6, 10.5}}]}, {
     LineBox[{{6, 0.5}, {7, 0.5}}], LineBox[{{6, 1.5}, {7, 1.5}}], 
     LineBox[{{6, 2.5}, {7, 2.5}}], LineBox[{{6, 3.5}, {7, 3.5}}], 
     LineBox[{{6, 4.5}, {7, 4.5}}], LineBox[{{6, 5.5}, {7, 5.5}}], 
     LineBox[{{6, 6.5}, {7, 6.5}}], LineBox[{{6, 7.5}, {7, 7.5}}], 
     LineBox[{{6, 8.5}, {7, 8.5}}], LineBox[{{6, 9.5}, {7, 9.5}}], 
     LineBox[{{6, 10.5}, {7, 10.5}}]}, {LineBox[{{7, 0.5}, {8, 0.5}}], 
     LineBox[{{7, 1.5}, {8, 1.5}}], LineBox[{{7, 2.5}, {8, 2.5}}], 
     LineBox[{{7, 3.5}, {8, 3.5}}], LineBox[{{7, 4.5}, {8, 4.5}}], 
     LineBox[{{7, 5.5}, {8, 5.5}}], LineBox[{{7, 6.5}, {8, 6.5}}], 
     LineBox[{{7, 7.5}, {8, 7.5}}], LineBox[{{7, 8.5}, {8, 8.5}}], 
     LineBox[{{7, 9.5}, {8, 9.5}}], LineBox[{{7, 10.5}, {8, 10.5}}]}, {
     LineBox[{{8, 0.5}, {9, 0.5}}], LineBox[{{8, 1.5}, {9, 1.5}}], 
     LineBox[{{8, 2.5}, {9, 2.5}}], LineBox[{{8, 3.5}, {9, 3.5}}], 
     LineBox[{{8, 4.5}, {9, 4.5}}], LineBox[{{8, 5.5}, {9, 5.5}}], 
     LineBox[{{8, 6.5}, {9, 6.5}}], LineBox[{{8, 7.5}, {9, 7.5}}], 
     LineBox[{{8, 8.5}, {9, 8.5}}], LineBox[{{8, 9.5}, {9, 9.5}}], 
     LineBox[{{8, 10.5}, {9, 10.5}}]}, {LineBox[{{9, 0.5}, {10, 0.5}}], 
     LineBox[{{9, 1.5}, {10, 1.5}}], LineBox[{{9, 2.5}, {10, 2.5}}], 
     LineBox[{{9, 3.5}, {10, 3.5}}], LineBox[{{9, 4.5}, {10, 4.5}}], 
     LineBox[{{9, 5.5}, {10, 5.5}}], LineBox[{{9, 6.5}, {10, 6.5}}], 
     LineBox[{{9, 7.5}, {10, 7.5}}], LineBox[{{9, 8.5}, {10, 8.5}}], 
     LineBox[{{9, 9.5}, {10, 9.5}}], LineBox[{{9, 10.5}, {10, 10.5}}]}, {
     LineBox[{{10, 0.5}, {11, 0.5}}], LineBox[{{10, 1.5}, {11, 1.5}}], 
     LineBox[{{10, 2.5}, {11, 2.5}}], LineBox[{{10, 3.5}, {11, 3.5}}], 
     LineBox[{{10, 4.5}, {11, 4.5}}], LineBox[{{10, 5.5}, {11, 5.5}}], 
     LineBox[{{10, 6.5}, {11, 6.5}}], LineBox[{{10, 7.5}, {11, 7.5}}], 
     LineBox[{{10, 8.5}, {11, 8.5}}], LineBox[{{10, 9.5}, {11, 9.5}}], 
     LineBox[{{10, 10.5}, {11, 10.5}}]}, {LineBox[{{11, 0.5}, {12, 0.5}}], 
     LineBox[{{11, 1.5}, {12, 1.5}}], LineBox[{{11, 2.5}, {12, 2.5}}], 
     LineBox[{{11, 3.5}, {12, 3.5}}], LineBox[{{11, 4.5}, {12, 4.5}}], 
     LineBox[{{11, 5.5}, {12, 5.5}}], LineBox[{{11, 6.5}, {12, 6.5}}], 
     LineBox[{{11, 7.5}, {12, 7.5}}], LineBox[{{11, 8.5}, {12, 8.5}}], 
     LineBox[{{11, 9.5}, {12, 9.5}}], LineBox[{{11, 10.5}, {12, 10.5}}]}, {
     LineBox[{{12, 0.5}, {13, 0.5}}], LineBox[{{12, 1.5}, {13, 1.5}}], 
     LineBox[{{12, 2.5}, {13, 2.5}}], LineBox[{{12, 3.5}, {13, 3.5}}], 
     LineBox[{{12, 4.5}, {13, 4.5}}], LineBox[{{12, 5.5}, {13, 5.5}}], 
     LineBox[{{12, 6.5}, {13, 6.5}}], LineBox[{{12, 7.5}, {13, 7.5}}], 
     LineBox[{{12, 8.5}, {13, 8.5}}], LineBox[{{12, 9.5}, {13, 9.5}}], 
     LineBox[{{12, 10.5}, {13, 10.5}}]}, {LineBox[{{13, 0.5}, {14, 0.5}}], 
     LineBox[{{13, 1.5}, {14, 1.5}}], LineBox[{{13, 2.5}, {14, 2.5}}], 
     LineBox[{{13, 3.5}, {14, 3.5}}], LineBox[{{13, 4.5}, {14, 4.5}}], 
     LineBox[{{13, 5.5}, {14, 5.5}}], LineBox[{{13, 6.5}, {14, 6.5}}], 
     LineBox[{{13, 7.5}, {14, 7.5}}], LineBox[{{13, 8.5}, {14, 8.5}}], 
     LineBox[{{13, 9.5}, {14, 9.5}}], LineBox[{{13, 10.5}, {14, 10.5}}]}, {
     LineBox[{{14, 0.5}, {15, 0.5}}], LineBox[{{14, 1.5}, {15, 1.5}}], 
     LineBox[{{14, 2.5}, {15, 2.5}}], LineBox[{{14, 3.5}, {15, 3.5}}], 
     LineBox[{{14, 4.5}, {15, 4.5}}], LineBox[{{14, 5.5}, {15, 5.5}}], 
     LineBox[{{14, 6.5}, {15, 6.5}}], LineBox[{{14, 7.5}, {15, 7.5}}], 
     LineBox[{{14, 8.5}, {15, 8.5}}], LineBox[{{14, 9.5}, {15, 9.5}}], 
     LineBox[{{14, 10.5}, {15, 10.5}}]}, {LineBox[{{15, 0.5}, {16, 0.5}}], 
     LineBox[{{15, 1.5}, {16, 1.5}}], LineBox[{{15, 2.5}, {16, 2.5}}], 
     LineBox[{{15, 3.5}, {16, 3.5}}], LineBox[{{15, 4.5}, {16, 4.5}}], 
     LineBox[{{15, 5.5}, {16, 5.5}}], LineBox[{{15, 6.5}, {16, 6.5}}], 
     LineBox[{{15, 7.5}, {16, 7.5}}], LineBox[{{15, 8.5}, {16, 8.5}}], 
     LineBox[{{15, 9.5}, {16, 9.5}}], LineBox[{{15, 10.5}, {16, 10.5}}]}, {
     LineBox[{{16, 0.5}, {17, 0.5}}], LineBox[{{16, 1.5}, {17, 1.5}}], 
     LineBox[{{16, 2.5}, {17, 2.5}}], LineBox[{{16, 3.5}, {17, 3.5}}], 
     LineBox[{{16, 4.5}, {17, 4.5}}], LineBox[{{16, 5.5}, {17, 5.5}}], 
     LineBox[{{16, 6.5}, {17, 6.5}}], LineBox[{{16, 7.5}, {17, 7.5}}], 
     LineBox[{{16, 8.5}, {17, 8.5}}], LineBox[{{16, 9.5}, {17, 9.5}}], 
     LineBox[{{16, 10.5}, {17, 10.5}}]}, {LineBox[{{17, 0.5}, {18, 0.5}}], 
     LineBox[{{17, 1.5}, {18, 1.5}}], LineBox[{{17, 2.5}, {18, 2.5}}], 
     LineBox[{{17, 3.5}, {18, 3.5}}], LineBox[{{17, 4.5}, {18, 4.5}}], 
     LineBox[{{17, 5.5}, {18, 5.5}}], LineBox[{{17, 6.5}, {18, 6.5}}], 
     LineBox[{{17, 7.5}, {18, 7.5}}], LineBox[{{17, 8.5}, {18, 8.5}}], 
     LineBox[{{17, 9.5}, {18, 9.5}}], LineBox[{{17, 10.5}, {18, 10.5}}]}, {
     LineBox[{{18, 0.5}, {19, 0.5}}], LineBox[{{18, 1.5}, {19, 1.5}}], 
     LineBox[{{18, 2.5}, {19, 2.5}}], LineBox[{{18, 3.5}, {19, 3.5}}], 
     LineBox[{{18, 4.5}, {19, 4.5}}], LineBox[{{18, 5.5}, {19, 5.5}}], 
     LineBox[{{18, 6.5}, {19, 6.5}}], LineBox[{{18, 7.5}, {19, 7.5}}], 
     LineBox[{{18, 8.5}, {19, 8.5}}], LineBox[{{18, 9.5}, {19, 9.5}}], 
     LineBox[{{18, 10.5}, {19, 10.5}}]}, {LineBox[{{19, 0.5}, {20, 0.5}}], 
     LineBox[{{19, 1.5}, {20, 1.5}}], LineBox[{{19, 2.5}, {20, 2.5}}], 
     LineBox[{{19, 3.5}, {20, 3.5}}], LineBox[{{19, 4.5}, {20, 4.5}}], 
     LineBox[{{19, 5.5}, {20, 5.5}}], LineBox[{{19, 6.5}, {20, 6.5}}], 
     LineBox[{{19, 7.5}, {20, 7.5}}], LineBox[{{19, 8.5}, {20, 8.5}}], 
     LineBox[{{19, 9.5}, {20, 9.5}}], LineBox[{{19, 10.5}, {20, 10.5}}]}, {
     LineBox[{{20, 0.5}, {21, 0.5}}], LineBox[{{20, 1.5}, {21, 1.5}}], 
     LineBox[{{20, 2.5}, {21, 2.5}}], LineBox[{{20, 3.5}, {21, 3.5}}], 
     LineBox[{{20, 4.5}, {21, 4.5}}], LineBox[{{20, 5.5}, {21, 5.5}}], 
     LineBox[{{20, 6.5}, {21, 6.5}}], LineBox[{{20, 7.5}, {21, 7.5}}], 
     LineBox[{{20, 8.5}, {21, 8.5}}], LineBox[{{20, 9.5}, {21, 9.5}}], 
     LineBox[{{20, 10.5}, {21, 10.5}}]}, {LineBox[{{21, 0.5}, {22, 0.5}}], 
     LineBox[{{21, 1.5}, {22, 1.5}}], LineBox[{{21, 2.5}, {22, 2.5}}], 
     LineBox[{{21, 3.5}, {22, 3.5}}], LineBox[{{21, 4.5}, {22, 4.5}}], 
     LineBox[{{21, 5.5}, {22, 5.5}}], LineBox[{{21, 6.5}, {22, 6.5}}], 
     LineBox[{{21, 7.5}, {22, 7.5}}], LineBox[{{21, 8.5}, {22, 8.5}}], 
     LineBox[{{21, 9.5}, {22, 9.5}}], LineBox[{{21, 10.5}, {22, 10.5}}]}, {
     LineBox[{{22, 0.5}, {23, 0.5}}], LineBox[{{22, 1.5}, {23, 1.5}}], 
     LineBox[{{22, 2.5}, {23, 2.5}}], LineBox[{{22, 3.5}, {23, 3.5}}], 
     LineBox[{{22, 4.5}, {23, 4.5}}], LineBox[{{22, 5.5}, {23, 5.5}}], 
     LineBox[{{22, 6.5}, {23, 6.5}}], LineBox[{{22, 7.5}, {23, 7.5}}], 
     LineBox[{{22, 8.5}, {23, 8.5}}], LineBox[{{22, 9.5}, {23, 9.5}}], 
     LineBox[{{22, 10.5}, {23, 10.5}}]}}, {{
     RectangleBox[{0.1, 4.1}, {0.9, 4.9}], 
     InsetBox["\<\"H\"\>", {0.5, 4.5}]}, {
     {FaceForm[GrayLevel[0]], DiskBox[{1.5, 4.5}, 0.1], 
      LineBox[{{1.5, 3.5}, {1.5, 4.5}}]}, {CircleBox[{1.5, 3.5}, 0.25], 
      LineBox[{{1.5, 3.25}, {1.5, 3.75}}]}}, 
    {EdgeForm[Dashing[{Small, Small}]], RectangleBox[{2.1, 3.1}, {2.9, 4.9}], 
     InsetBox["\<\"\[CapitalDelta]\"\>", {2.5, 4.}]}, {
     {FaceForm[GrayLevel[0]], DiskBox[{3.5, 3.5}, 0.1], 
      LineBox[{{3.5, 2.5}, {3.5, 3.5}}]}, {CircleBox[{3.5, 2.5}, 0.25], 
      LineBox[{{3.5, 2.25}, {3.5, 2.75}}]}}, 
    {EdgeForm[Dashing[{Small, Small}]], RectangleBox[{4.1, 2.1}, {4.9, 3.9}], 
     InsetBox["\<\"\[CapitalDelta]\"\>", {4.5, 3.}]}, {
     {FaceForm[GrayLevel[0]], DiskBox[{5.5, 2.5}, 0.1], 
      LineBox[{{5.5, 1.5}, {5.5, 2.5}}]}, {CircleBox[{5.5, 1.5}, 0.25], 
      LineBox[{{5.5, 1.25}, {5.5, 1.75}}]}}, 
    {EdgeForm[Dashing[{Small, Small}]], RectangleBox[{6.1, 1.1}, {6.9, 2.9}], 
     InsetBox["\<\"\[CapitalDelta]\"\>", {6.5, 2.}]}, {
     {FaceForm[GrayLevel[0]], DiskBox[{7.5, 1.5}, 0.1], 
      LineBox[{{7.5, 0.5}, {7.5, 1.5}}]}, {CircleBox[{7.5, 0.5}, 0.25], 
      LineBox[{{7.5, 0.25}, {7.5, 0.75}}]}}, 
    {EdgeForm[Dashing[{Small, Small}]], RectangleBox[{8.1, 0.1}, {8.9, 1.9}], 
     InsetBox["\<\"\[CapitalDelta]\"\>", {8.5, 1.}]}, {
     RectangleBox[{8.1, 9.1}, {8.9, 9.9}], 
     InsetBox["\<\"H\"\>", {8.5, 9.5}]}, {
     {FaceForm[GrayLevel[0]], DiskBox[{9.5, 9.5}, 0.1], 
      LineBox[{{9.5, 8.5}, {9.5, 9.5}}]}, {CircleBox[{9.5, 8.5}, 0.25], 
      LineBox[{{9.5, 8.25}, {9.5, 8.75}}]}}, 
    {EdgeForm[Dashing[{Small, Small}]], 
     RectangleBox[{10.1, 8.1}, {10.9, 9.9}], 
     InsetBox["\<\"\[CapitalDelta]\"\>", {10.5, 9.}]}, {
     {FaceForm[GrayLevel[0]], DiskBox[{11.5, 8.5}, 0.1], 
      LineBox[{{11.5, 7.5}, {11.5, 8.5}}]}, {CircleBox[{11.5, 7.5}, 0.25], 
      LineBox[{{11.5, 7.25}, {11.5, 7.75}}]}}, 
    {EdgeForm[Dashing[{Small, Small}]], 
     RectangleBox[{12.1, 7.1}, {12.9, 8.9}], 
     InsetBox["\<\"\[CapitalDelta]\"\>", {12.5, 8.}]}, {
     {FaceForm[GrayLevel[0]], DiskBox[{13.5, 7.5}, 0.1], 
      LineBox[{{13.5, 6.5}, {13.5, 7.5}}]}, {CircleBox[{13.5, 6.5}, 0.25], 
      LineBox[{{13.5, 6.25}, {13.5, 6.75}}]}}, 
    {EdgeForm[Dashing[{Small, Small}]], 
     RectangleBox[{14.1, 6.1}, {14.9, 7.9}], 
     InsetBox["\<\"\[CapitalDelta]\"\>", {14.5, 7.}]}, {
     {FaceForm[GrayLevel[0]], DiskBox[{15.5, 6.5}, 0.1], 
      LineBox[{{15.5, 5.5}, {15.5, 6.5}}]}, {CircleBox[{15.5, 5.5}, 0.25], 
      LineBox[{{15.5, 5.25}, {15.5, 5.75}}]}}, 
    {EdgeForm[Dashing[{Small, Small}]], 
     RectangleBox[{16.1, 5.1}, {16.9, 6.9}], 
     InsetBox["\<\"\[CapitalDelta]\"\>", {16.5, 6.}]}, {
     RectangleBox[{16.1, 10.1}, {16.9, 10.9}], 
     InsetBox["\<\"H\"\>", {16.5, 10.5}]}, {
     {FaceForm[GrayLevel[0]], DiskBox[{17.5, 10.5}, 0.1], 
      LineBox[{{17.5, 0.5}, {17.5, 
       10.5}}]}, {{{LineBox[{{17.4, 0.4}, {17.6, 0.6}}], 
        LineBox[{{17.6, 0.4}, {17.4, 0.6}}]}, {
        LineBox[{{17.4, 5.4}, {17.6, 5.6}}], 
        LineBox[{{17.6, 5.4}, {17.4, 5.6}}]}}, 
      LineBox[{{17.5, 0.5}, {17.5, 5.5}}]}}, {
     {FaceForm[GrayLevel[0]], DiskBox[{18.5, 10.5}, 0.1], 
      LineBox[{{18.5, 1.5}, {18.5, 
       10.5}}]}, {{{LineBox[{{18.4, 1.4}, {18.6, 1.6}}], 
        LineBox[{{18.6, 1.4}, {18.4, 1.6}}]}, {
        LineBox[{{18.4, 6.4}, {18.6, 6.6}}], 
        LineBox[{{18.6, 6.4}, {18.4, 6.6}}]}}, 
      LineBox[{{18.5, 1.5}, {18.5, 6.5}}]}}, {
     {FaceForm[GrayLevel[0]], DiskBox[{19.5, 10.5}, 0.1], 
      LineBox[{{19.5, 2.5}, {19.5, 
       10.5}}]}, {{{LineBox[{{19.4, 2.4}, {19.6, 2.6}}], 
        LineBox[{{19.6, 2.4}, {19.4, 2.6}}]}, {
        LineBox[{{19.4, 7.4}, {19.6, 7.6}}], 
        LineBox[{{19.6, 7.4}, {19.4, 7.6}}]}}, 
      LineBox[{{19.5, 2.5}, {19.5, 7.5}}]}}, {
     {FaceForm[GrayLevel[0]], DiskBox[{20.5, 10.5}, 0.1], 
      LineBox[{{20.5, 3.5}, {20.5, 
       10.5}}]}, {{{LineBox[{{20.4, 3.4}, {20.6, 3.6}}], 
        LineBox[{{20.6, 3.4}, {20.4, 3.6}}]}, {
        LineBox[{{20.4, 8.4}, {20.6, 8.6}}], 
        LineBox[{{20.6, 8.4}, {20.4, 8.6}}]}}, 
      LineBox[{{20.5, 3.5}, {20.5, 8.5}}]}}, {
     {FaceForm[GrayLevel[0]], DiskBox[{21.5, 10.5}, 0.1], 
      LineBox[{{21.5, 4.5}, {21.5, 
       10.5}}]}, {{{LineBox[{{21.4, 4.4}, {21.6, 4.6}}], 
        LineBox[{{21.6, 4.4}, {21.4, 4.6}}]}, {
        LineBox[{{21.4, 9.4}, {21.6, 9.6}}], 
        LineBox[{{21.6, 9.4}, {21.4, 9.6}}]}}, 
      LineBox[{{21.5, 4.5}, {21.5, 9.5}}]}}, {}, {
     RectangleBox[{22.1, 10.1}, {22.9, 10.9}], 
     InsetBox["\<\"H\"\>", {22.5, 10.5}]}}},
  Epilog->{
    FaceForm[None], 
    EdgeForm[
     Directive[
      RGBColor[1, 0, 0], 
      Dashing[{Small, Small}]]], 
    InsetBox[
     FormBox[
      StyleBox[
       InterpretationBox[
       "\"Reg. \\!\\(\\*FormBox[\\\"0\\\", TraditionalForm]\\)\"", 
        StringForm["Reg. ``", 0], Editable -> False], FontSize -> 12, 
       StripOnInput -> False], TraditionalForm], {0, 0.4}, {-1, -1}], 
    EdgeForm[
     Directive[
      RGBColor[1, 0, 0], 
      Dashing[{Small, Small}], 
      Opacity[0.4]]], 
    RectangleBox[{0, 0.2}, {26, 4.8}], 
    InsetBox[
     FormBox[
      StyleBox[
       InterpretationBox[
       "\"Reg. \\!\\(\\*FormBox[\\\"1\\\", TraditionalForm]\\)\"", 
        StringForm["Reg. ``", 1], Editable -> False], FontSize -> 12, 
       StripOnInput -> False], TraditionalForm], {0, 5.4}, {-1, -1}], 
    EdgeForm[
     Directive[
      RGBColor[0, 0, 1], 
      Dashing[{Small, Small}], 
      Opacity[0.4]]], 
    RectangleBox[{0, 5.2}, {26, 9.8}]},
  ImageSize->690,
  Method->{"ShrinkWrap" -> True}]], "Output",
 CellChangeTimes->{{3.8272412527184477`*^9, 3.827241256479639*^9}, {
   3.8272421020216827`*^9, 3.827242131340679*^9}, 3.827242551590004*^9, 
   3.827242829201681*^9},
 CellLabel->"Out[35]=",ExpressionUUID->"d2b1f70f-bd26-46c9-a096-20854434b829"]
}, Open  ]],

Cell[TextData[{
 "Simulate the circuit in QuESTlink and compute the probability on the \
ancilla qubit as ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     RowBox[{"prob", "'"}], "0"], "="}], TraditionalForm]],ExpressionUUID->
  "4d24cb51-0eb4-4126-a5e6-67e3030208f8"],
 Cell[BoxData[
  FormBox[
   RowBox[{"Tr", "[", 
    SuperscriptBox["\[Rho]", "2"]}], TraditionalForm]],ExpressionUUID->
  "a3c39753-2260-4517-87de-3f28a03b53c7"],
 "]"
}], "Text",
 CellChangeTimes->{{3.8262650902861843`*^9, 3.826265091099492*^9}, {
   3.8262652312441196`*^9, 3.826265473334661*^9}, {3.8264936657315893`*^9, 
   3.826493710958598*^9}, {3.826493827200305*^9, 3.8264938282809477`*^9}, {
   3.8264939742007303`*^9, 3.82649405518382*^9}, {3.8272392140975666`*^9, 
   3.827239224966739*^9}, {3.827239268488271*^9, 3.8272392931488256`*^9}, {
   3.827239343424307*^9, 3.8272393559192715`*^9}, {3.8272395839220505`*^9, 
   3.827239589466489*^9}, {3.827240071375389*^9, 3.8272400906643705`*^9}, {
   3.8272401554151773`*^9, 3.8272401678247633`*^9}, {3.8272402594347553`*^9, 
   3.827240276773361*^9}, {3.8272403088310623`*^9, 3.8272404918762016`*^9}, {
   3.8272407721152735`*^9, 3.8272407728647995`*^9}, {3.827240808213707*^9, 
   3.827240831829824*^9}, 3.8272409247161636`*^9, {3.82724109514158*^9, 
   3.8272411110757155`*^9}, {3.8272411752391224`*^9, 3.82724122372865*^9}, {
   3.827241897225638*^9, 3.827242017278228*^9}, {3.827242052864476*^9, 
   3.827242076348015*^9}, {3.827242773914975*^9, 3.8272427758897667`*^9}, {
   3.827244286191642*^9, 3.8272442863292074`*^9}},
 Background->RGBColor[
  0.88, 1, 0.88],ExpressionUUID->"1c7aae1e-252a-4d7a-93a2-339c2e3ca655"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ApplyCircuit", "[", 
   RowBox[{"fullCircId", ",", 
    RowBox[{"InitZeroState", "@", "\[Rho]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"prob0Prime", "=", 
   RowBox[{
    RowBox[{"2", 
     RowBox[{"CalcProbOfOutcome", "[", 
      RowBox[{"\[Rho]", ",", 
       RowBox[{"2", "*", "numQs"}], ",", "0"}], "]"}]}], "-", "1"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.8260221893071127`*^9, 3.8260222825498495`*^9}, {
   3.826022469581562*^9, 3.8260224793649344`*^9}, {3.82602266522556*^9, 
   3.826022872518877*^9}, {3.826022910424039*^9, 3.8260229355516148`*^9}, {
   3.8260230157287035`*^9, 3.826023016590984*^9}, {3.826023061207801*^9, 
   3.826023249188407*^9}, {3.826025662328537*^9, 3.8260256627417865`*^9}, {
   3.8261766575433617`*^9, 3.8261766746370945`*^9}, {3.82687221409792*^9, 
   3.826872298944437*^9}, {3.826872445536232*^9, 3.826872502337929*^9}, {
   3.826875424212309*^9, 3.826875438519244*^9}, {3.826875474013958*^9, 
   3.8268756945917215`*^9}, {3.8268757375296392`*^9, 
   3.8268757926805105`*^9}, {3.8268759669650035`*^9, 
   3.8268759748505483`*^9}, {3.8268760062361517`*^9, 
   3.8268760110297503`*^9}, {3.826876048843635*^9, 3.8268760639415426`*^9}, {
   3.8268760950731826`*^9, 3.826876108676964*^9}, {3.826876139476552*^9, 
   3.826876188526916*^9}, {3.8268762922134504`*^9, 3.826876298421209*^9}, {
   3.8268763285460463`*^9, 3.826876415044627*^9}, {3.8268764645352354`*^9, 
   3.8268765126869345`*^9}, {3.8268767633496466`*^9, 3.826876767015259*^9}, {
   3.826877054815946*^9, 3.826877182333853*^9}, {3.826877434315336*^9, 
   3.826877642039488*^9}, {3.8268776761142864`*^9, 3.8268776778223376`*^9}, {
   3.8268777354507465`*^9, 3.826877753659024*^9}, {3.826877803061338*^9, 
   3.8268781013373165`*^9}, {3.82687815670776*^9, 3.8268781913222213`*^9}, {
   3.826878255480506*^9, 3.826878256230062*^9}, {3.8268782939854426`*^9, 
   3.8268784105487747`*^9}, {3.826878467393312*^9, 3.826878472315739*^9}, {
   3.8268785396075573`*^9, 3.8268785477423663`*^9}, {3.8268785971541195`*^9, 
   3.8268786408727407`*^9}, {3.826878726663971*^9, 3.8268787977741084`*^9}, {
   3.8268788427636986`*^9, 3.8268788428420963`*^9}, {3.8268789007429075`*^9, 
   3.8268789102054234`*^9}, {3.8268789935417876`*^9, 3.826878993639367*^9}, {
   3.8268866538873425`*^9, 3.8268866565472975`*^9}, {3.826887031413435*^9, 
   3.8268870319487658`*^9}, {3.826887068730373*^9, 3.82688706888705*^9}, {
   3.8268872985753403`*^9, 3.826887330476345*^9}, {3.8268875278843155`*^9, 
   3.8268875453908625`*^9}, {3.826887622827999*^9, 3.8268876570495176`*^9}, {
   3.8268942296195645`*^9, 3.826894237335995*^9}, {3.8268942735010242`*^9, 
   3.8268942789502306`*^9}, {3.826896298877681*^9, 3.8268962997279787`*^9}, {
   3.8268964067279987`*^9, 3.8268964070139527`*^9}, {3.82695035607237*^9, 
   3.8269503650855494`*^9}, {3.8272399892743073`*^9, 3.827239992707729*^9}, {
   3.8272414783701763`*^9, 3.827241509973797*^9}, {3.8272418207737827`*^9, 
   3.8272418221987405`*^9}, 3.827241884332384*^9, {3.827242082342699*^9, 
   3.827242086467037*^9}, {3.827242156698113*^9, 3.8272421582782726`*^9}},
 CellLabel->"In[36]:=",ExpressionUUID->"13ea882f-0504-4b60-a7db-6c7bf32c92e9"],

Cell[TextData[{
 "The mitigated expectation value is computed via the ratio ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["prob", "0"], "/", 
    SubscriptBox[
     RowBox[{"prob", "'"}], "0"]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "f37d1bee-2254-49e6-81a7-dcd1b4ee2e95"]
}], "Text",
 CellChangeTimes->{{3.8262650902861843`*^9, 3.826265091099492*^9}, {
   3.8262652312441196`*^9, 3.826265473334661*^9}, {3.8264936657315893`*^9, 
   3.826493710958598*^9}, {3.826493827200305*^9, 3.8264938282809477`*^9}, {
   3.8264939742007303`*^9, 3.82649405518382*^9}, {3.8272392140975666`*^9, 
   3.827239224966739*^9}, {3.827239268488271*^9, 3.8272392931488256`*^9}, {
   3.827239343424307*^9, 3.8272393559192715`*^9}, {3.8272395839220505`*^9, 
   3.827239589466489*^9}, {3.827240071375389*^9, 3.8272400906643705`*^9}, {
   3.8272401554151773`*^9, 3.8272401678247633`*^9}, {3.8272402594347553`*^9, 
   3.827240276773361*^9}, {3.8272403088310623`*^9, 3.8272404918762016`*^9}, {
   3.8272407721152735`*^9, 3.8272407728647995`*^9}, {3.827240808213707*^9, 
   3.827240831829824*^9}, 3.8272409247161636`*^9, {3.82724109514158*^9, 
   3.8272411110757155`*^9}, {3.8272411752391224`*^9, 3.82724122372865*^9}, {
   3.827241897225638*^9, 3.827242017278228*^9}, {3.827242052864476*^9, 
   3.827242076348015*^9}, {3.8272421731653633`*^9, 3.827242213017477*^9}},
 Background->RGBColor[
  0.88, 1, 0.88],ExpressionUUID->"1b4de1d4-abeb-4430-ac5c-fc42b08bdde9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mitigatedExp", "=", 
  RowBox[{"prob0", "/", "prob0Prime"}]}]], "Input",
 CellChangeTimes->{{3.827242253268775*^9, 3.8272422557128983`*^9}, {
  3.827242803432784*^9, 3.8272428052704964`*^9}},
 CellLabel->"In[38]:=",ExpressionUUID->"7a6c942b-a7e1-40b7-b49f-ae696a82c5b8"],

Cell[BoxData["0.9998319592639485`"], "Output",
 CellChangeTimes->{
  3.8272422567034507`*^9, 3.8272425529092836`*^9, {3.8272428055204544`*^9, 
   3.827242830705021*^9}},
 CellLabel->"Out[38]=",ExpressionUUID->"e2ca6c6f-ae20-4899-8141-990a4b886b57"]
}, Open  ]],

Cell["\<\
Observe that the mitigated error is significantly smaller than the \
unmitigated one\
\>", "Text",
 CellChangeTimes->{{3.8262650902861843`*^9, 3.826265091099492*^9}, {
   3.8262652312441196`*^9, 3.826265473334661*^9}, {3.8264936657315893`*^9, 
   3.826493710958598*^9}, {3.826493827200305*^9, 3.8264938282809477`*^9}, {
   3.8264939742007303`*^9, 3.82649405518382*^9}, {3.8272392140975666`*^9, 
   3.827239224966739*^9}, {3.827239268488271*^9, 3.8272392931488256`*^9}, {
   3.827239343424307*^9, 3.8272393559192715`*^9}, {3.8272395839220505`*^9, 
   3.827239589466489*^9}, {3.827240071375389*^9, 3.8272400906643705`*^9}, {
   3.8272401554151773`*^9, 3.8272401678247633`*^9}, {3.8272402594347553`*^9, 
   3.827240276773361*^9}, {3.8272403088310623`*^9, 3.8272404918762016`*^9}, {
   3.8272407721152735`*^9, 3.8272407728647995`*^9}, {3.827240808213707*^9, 
   3.827240831829824*^9}, 3.8272409247161636`*^9, {3.82724109514158*^9, 
   3.8272411110757155`*^9}, {3.8272411752391224`*^9, 3.82724122372865*^9}, {
   3.827241897225638*^9, 3.827242017278228*^9}, {3.827242052864476*^9, 
   3.827242076348015*^9}, {3.8272421731653633`*^9, 3.827242248014205*^9}, {
   3.827242824087994*^9, 3.8272428288536186`*^9}, {3.8272442778006916`*^9, 
   3.827244278662634*^9}},
 Background->RGBColor[
  0.88, 1, 0.88],ExpressionUUID->"edb6f6d2-5636-4928-92f2-76db6e897b2d"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"errorWithDerangement", "=", 
  RowBox[{"Abs", "[", 
   RowBox[{"mitigatedExp", "-", "idealExpectation"}], 
   "]"}]}], "\[IndentingNewLine]", "unmitigatedError"}], "Input",
 CellChangeTimes->{{3.8272422175828547`*^9, 3.8272422252150183`*^9}, {
  3.827242263914302*^9, 3.827242270207252*^9}},
 CellLabel->"In[39]:=",ExpressionUUID->"fea5f61e-c97c-47d6-9977-11a25b31a430"],

Cell[BoxData["0.00016804073605147796`"], "Output",
 CellChangeTimes->{
  3.827242213848153*^9, {3.8272422644018984`*^9, 3.827242270453176*^9}, 
   3.8272425529545393`*^9, 3.8272428307580433`*^9},
 CellLabel->"Out[39]=",ExpressionUUID->"3256dc7e-56c5-4776-9089-11a9ad64fbac"],

Cell[BoxData["0.041988841573136204`"], "Output",
 CellChangeTimes->{
  3.827242213848153*^9, {3.8272422644018984`*^9, 3.827242270453176*^9}, 
   3.8272425529545393`*^9, 3.827242830761072*^9},
 CellLabel->"Out[40]=",ExpressionUUID->"d8d858a9-ee6c-439c-b459-facbed08f49e"]
}, Open  ]],

Cell[TextData[StyleBox["Try to vary the noise rate \[Epsilon] above and see \
how it changes the mitigated and unmitigated errors (see plot in the advanced \
notebook)",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.8262650902861843`*^9, 3.826265091099492*^9}, {
   3.8262652312441196`*^9, 3.826265473334661*^9}, {3.8264936657315893`*^9, 
   3.826493710958598*^9}, {3.826493827200305*^9, 3.8264938282809477`*^9}, {
   3.8264939742007303`*^9, 3.82649405518382*^9}, {3.8272392140975666`*^9, 
   3.827239224966739*^9}, {3.827239268488271*^9, 3.8272392931488256`*^9}, {
   3.827239343424307*^9, 3.8272393559192715`*^9}, {3.8272395839220505`*^9, 
   3.827239589466489*^9}, {3.827240071375389*^9, 3.8272400906643705`*^9}, {
   3.8272401554151773`*^9, 3.8272401678247633`*^9}, {3.8272402594347553`*^9, 
   3.827240276773361*^9}, {3.8272403088310623`*^9, 3.8272404918762016`*^9}, {
   3.8272407721152735`*^9, 3.8272407728647995`*^9}, {3.827240808213707*^9, 
   3.827240831829824*^9}, 3.8272409247161636`*^9, {3.82724109514158*^9, 
   3.8272411110757155`*^9}, {3.8272411752391224`*^9, 3.82724122372865*^9}, {
   3.827241897225638*^9, 3.827242017278228*^9}, {3.827242052864476*^9, 
   3.827242076348015*^9}, {3.8272421731653633`*^9, 3.827242248014205*^9}, {
   3.827242314000884*^9, 3.827242356572239*^9}, {3.827242845665056*^9, 
   3.827242853727707*^9}},
 Background->RGBColor[
  0.88, 1, 0.88],ExpressionUUID->"3482d965-ece0-4e03-873b-da19be1cd6d9"]
}, Open  ]]
},
WindowSize->{1289, 776},
WindowMargins->{{Automatic, 0}, {Automatic, 0}},
Magnification:>1.2 Inherited,
FrontEndVersion->"12.0 for Microsoft Windows (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 1276, 26, 115, "Text",ExpressionUUID->"edeb8f40-1ecb-4621-b0ed-e34a18b3ac59"],
Cell[CellGroupData[{
Cell[1859, 50, 390, 6, 66, "Subsubsection",ExpressionUUID->"ba6a1eed-b2ed-4d6f-b84e-545b036530a8"],
Cell[2252, 58, 672, 10, 61, "Text",ExpressionUUID->"fce6512a-b7da-4a04-a168-df801fcf3997"],
Cell[2927, 70, 9244, 211, 828, "Input",ExpressionUUID->"206d4c26-824c-4345-86ef-8a66327a263c",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[12208, 286, 537, 8, 66, "Subsubsection",ExpressionUUID->"b7b1cfe5-09e0-40fc-95c1-309abf21c5d5"],
Cell[12748, 296, 628, 9, 61, "Text",ExpressionUUID->"f2b76694-ba70-4719-849d-be7a4b002b84"],
Cell[13379, 307, 150, 3, 35, "Input",ExpressionUUID->"33b879cf-e6ca-4316-b322-098e4ab28a86"],
Cell[13532, 312, 892, 14, 88, "Text",ExpressionUUID->"886cdb7c-cf6d-4354-acb6-d2664b14e1dc"],
Cell[CellGroupData[{
Cell[14449, 330, 427, 10, 35, "Input",ExpressionUUID->"7600486f-d235-451d-9ca0-eba4d35ae8c3"],
Cell[14879, 342, 389, 9, 39, "Output",ExpressionUUID->"a6f90732-60c2-4f78-9697-209810cedfff"]
}, Open  ]],
Cell[15283, 354, 974, 15, 61, "Text",ExpressionUUID->"fd25a2a7-3329-44d9-94af-200be9fd104c"],
Cell[CellGroupData[{
Cell[16282, 373, 998, 20, 84, "Input",ExpressionUUID->"7c2ec22a-c3ab-4a6c-b74f-3daf75b525f8"],
Cell[17283, 395, 8951, 163, 404, "Output",ExpressionUUID->"caa979f5-143c-4b95-8228-8642906ad792"]
}, Open  ]],
Cell[26249, 561, 916, 14, 61, "Text",ExpressionUUID->"f06827d5-1426-498f-b0de-e1c893feff36"],
Cell[CellGroupData[{
Cell[27190, 579, 251, 5, 35, "Input",ExpressionUUID->"ab8e87a1-8c7b-4f59-be5f-f60e74fc8f72"],
Cell[27444, 586, 226, 3, 39, "Output",ExpressionUUID->"53318b51-e05f-4b41-a19f-ab84fb5b1ca5"]
}, Open  ]]
}, Open  ]],
Cell[27697, 593, 468, 7, 66, "Subsubsection",ExpressionUUID->"abf6446b-d090-41d9-9302-d2b290512760"],
Cell[CellGroupData[{
Cell[28190, 604, 243, 4, 43, "Subsubsection",ExpressionUUID->"ac34b76b-d8c3-48a3-b731-92eb0e349739"],
Cell[28436, 610, 1181, 21, 63, "Text",ExpressionUUID->"a6f2a76d-5e5d-4f63-996d-35b069580392"],
Cell[CellGroupData[{
Cell[29642, 635, 1111, 31, 86, "Input",ExpressionUUID->"10b0ac48-97dc-425f-8ed4-7dc62a8118a4"],
Cell[30756, 668, 3264, 52, 194, "Output",ExpressionUUID->"a370b5c7-5fe8-4b3d-837c-8641716e0955"]
}, Open  ]],
Cell[34035, 723, 1030, 14, 61, "Text",ExpressionUUID->"ea961777-5a5f-4964-bd20-556aa961db21"],
Cell[35068, 739, 512, 12, 60, "Input",ExpressionUUID->"dfe7c3e3-6b1c-4042-b3ea-646cacc55456"],
Cell[35583, 753, 1391, 26, 61, "Text",ExpressionUUID->"58d5db4f-a10f-4166-922d-697cc41f016d"],
Cell[CellGroupData[{
Cell[36999, 783, 1526, 32, 60, "Input",ExpressionUUID->"652dfccf-a0aa-4311-88df-76a7a9e5acf9"],
Cell[38528, 817, 437, 6, 39, "Output",ExpressionUUID->"863bc678-62ea-4efd-8d9a-6443f29192c0"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[39014, 829, 581, 10, 53, "Subsubsection",ExpressionUUID->"9dae5ff9-7f30-4a2f-9128-8a0abdd94fc0"],
Cell[39598, 841, 1564, 28, 61, "Text",ExpressionUUID->"dd6b1fdb-4cef-4926-a9c6-8a959386b219"],
Cell[CellGroupData[{
Cell[41187, 873, 670, 16, 84, "Input",ExpressionUUID->"c62638dd-14d4-43e8-bb4e-97cea1b529fc"],
Cell[41860, 891, 17909, 296, 403, "Output",ExpressionUUID->"e32eb7a6-39ae-4a39-894e-f7f5079b1b59"]
}, Open  ]],
Cell[59784, 1190, 1893, 41, 64, "Text",ExpressionUUID->"afe72775-5f82-4006-b1f2-f4aa6fd7e2c3"],
Cell[61680, 1233, 753, 21, 84, "Input",ExpressionUUID->"37f1dc96-13e9-449a-9660-cc93409819df"],
Cell[62436, 1256, 1167, 17, 61, "Text",ExpressionUUID->"65b9a174-57ae-4a9d-aecb-7ded2ef16b60"],
Cell[CellGroupData[{
Cell[63628, 1277, 3467, 54, 84, "Input",ExpressionUUID->"3bf20ede-d40f-479f-ac1a-c40499e5ea97"],
Cell[67098, 1333, 14987, 254, 402, "Output",ExpressionUUID->"d2b1f70f-bd26-46c9-a096-20854434b829"]
}, Open  ]],
Cell[82100, 1590, 1665, 32, 64, "Text",ExpressionUUID->"1c7aae1e-252a-4d7a-93a2-339c2e3ca655"],
Cell[83768, 1624, 3222, 51, 60, "Input",ExpressionUUID->"13ea882f-0504-4b60-a7db-6c7bf32c92e9"],
Cell[86993, 1677, 1478, 26, 61, "Text",ExpressionUUID->"1b4de1d4-abeb-4430-ac5c-fc42b08bdde9"],
Cell[CellGroupData[{
Cell[88496, 1707, 294, 5, 35, "Input",ExpressionUUID->"7a6c942b-a7e1-40b7-b49f-ae696a82c5b8"],
Cell[88793, 1714, 248, 4, 39, "Output",ExpressionUUID->"e2ca6c6f-ae20-4899-8141-990a4b886b57"]
}, Open  ]],
Cell[89056, 1721, 1361, 21, 61, "Text",ExpressionUUID->"edb6f6d2-5636-4928-92f2-76db6e897b2d"],
Cell[CellGroupData[{
Cell[90442, 1746, 395, 7, 60, "Input",ExpressionUUID->"fea5f61e-c97c-47d6-9977-11a25b31a430"],
Cell[90840, 1755, 274, 4, 39, "Output",ExpressionUUID->"3256dc7e-56c5-4776-9089-11a9ad64fbac"],
Cell[91117, 1761, 270, 4, 39, "Output",ExpressionUUID->"d8d858a9-ee6c-439c-b459-facbed08f49e"]
}, Open  ]],
Cell[91402, 1768, 1449, 21, 61, "Text",ExpressionUUID->"3482d965-ece0-4e03-873b-da19be1cd6d9"]
}, Open  ]]
}
]
*)

